/**************************************************************************
	ADOBE SYSTEMS INCORPORATED
	 Copyright 2012 Adobe Systems Incorporated
	 All Rights Reserved.

	NOTICE:  Adobe permits you to use, modify, and distribute this file
	in accordance with the terms of the Adobe license agreement accompanying
	it.  If you have received this file from a source other than Adobe, then
	your use, modification, or distribution of it requires the prior written
	permission of Adobe.
**************************************************************************/

import com.adobe.csxs.core.CSXSInterface;
import com.adobe.csxs.events.*;
import com.adobe.csxs.types.*;

import mx.collections.*;
import mx.core.*;
import mx.events.ItemClickEvent;
import mx.styles.StyleManager;


[Bindable] private var panelWidth:Number = 290;
[Bindable] private var panelHeight:Number = 525;
[Bindable] private var fontSize:Number = 10;
[Bindable] private var arrowOffset:Number = 122;

public var strResetText:String;
public var strMessagesText:String;
public var strHelpText:String;
public var strGoFlyText:String;
public var csxs:CSXSInterface;
public var showErrors:Boolean = true;
public var strVersionText:String = "Version 1.0.0"; // REAL VERSION IS IN JSX FILE
public var blackTextColor:Number = 0; // i get this from the label, it is the default
public var whiteTextColor:Number = 13555671; // Red 206, green 215, blue 215
public var greenTextColor:Number = 26214; // the doctor recommends two of these every morning
public var defaultDisabledColor:Number = 0;
public var defaultFillColors:Object = null;
public var showHelpMessage:Boolean = true;
public var showStepMessage:Boolean = true;

public var enabledStep:Number = 1;

[Embed(source='Button1.png')] 
private var btn1Icn:Class;
 
[Embed(source='Button1_rollover.png')]
private var btn1RolloverIcn:Class;
 

[Embed(source='StartOver.png')]
 private var startOverIcn:Class;
 
[Embed(source='StartOver_rollover.png')]
 private var startOverRolloverIcn:Class;
 

/**
 * Function:		getGeometry
 * Description:		Force the size of the window all the time because I don't resize well
 */
private function getGeometry():WindowGeometry {
	var panel_X:Number = 100;
	var panel_Y:Number = 100;
	var panel_W:Number = panelWidth;
	var panel_H:Number = panelHeight;
	var windowsize:WindowGeometry = new WindowGeometry(panel_X,panel_Y,panel_W,panel_H);
	return windowsize;
}

/**
 * Function:		appReskinEvent
 * Description:		Photoshop can now do four colors, change our background and other stuff accordingly
 */
private function appReskinEvent(e:Event):void {
	var result:SyncRequestResult = csxs.getHostEnvironment();
   	if (SyncRequestResult.COMPLETE == result.status) {
		var hostData:HostEnvironment = result.data;
		var skinInfo:AppSkinInfo = hostData.appSkinInfo;
		setColors(skinInfo.panelBackgroundColor.color.rgb);
	}
}

private function setColors(c:Number):void {
	this.setStyle("backgroundGradientColors", [c, c]);
}

private function disableAllButtons():void {
	btn2.enabled = 	
	btn3.enabled =
	btn35.enabled = 
	btn4.enabled =
	btn5.enabled =
	btn6.enabled =
	btn7.enabled =
	btn8.enabled =
	btn9.enabled = false;
}

private function clickEvt(event:ItemClickEvent):void {
    var targetComp:TabBar = TabBar(event.currentTarget);
    if (event.index == 0) {
    	viewStack.selectedChild = mainView;
    } else {
    	viewStack.selectedChild = helpView;
    }
} 

private function stepClick(inStep:Number):void {
	disableAllButtons();
	switch (inStep) {
	case 1:
		if (enabledStep == 1) {
			enabledStep = 2;
			btn1.setStyle("icon", this["startOverIcn"]);
			btn1.setStyle("overIcon", this["startOverRolloverIcn"]);
			btn2.enabled = true;
		} else {
			enabledStep = 1;
			btn2.enabled = btn1.enabled = true;
			btn1.setStyle("icon", this["btn1Icn"]);
			btn1.setStyle("overIcon", this["btn1RolloverIcn"]);
			inStep = 111;
		}
		break;
	case 2:
		enabledStep = 3;
		btn1.setStyle("icon", this["startOverIcn"]);
		btn1.setStyle("overIcon", this["startOverRolloverIcn"]);
		btn4.enabled = btn35.enabled = btn3.enabled = true;
		break;
	case 3:
	case 35:
		btn4.enabled = btn35.enabled = btn3.enabled = true;
		break;
	case 4:
		enabledStep = 5;
		btn5.enabled = true;
		break;
	case 5:
		enabledStep = 6;
		btn6.enabled = true;
		break;
	case 6:
		enabledStep = 7;
		btn7.enabled = true;
		break;
	case 7:
		enabledStep = 8;
		btn8.enabled = true;
		break;
	case 8:
		enabledStep = 9;
		btn9.enabled = true;
		break;
	case 9:
		enabledStep = 1;
		btn2.enabled = true;
		btn1.setStyle("icon", this["btn1Icn"]);
		btn1.setStyle("overIcon", this["btn1RolloverIcn"]);
		break;
	default:
	}
	
	var params:String = '';

	params = paramsToParams(inStep);

	saveCurrentSettings(params);

	csxs.evalScript("colourAssistant.runProcess", params);

}

/**
	Function:		init
	Description:	Initializes the size of the panel to a set size. The
					function also retrieves the Adobe Photoshop's host environment
					properties including the background color, font family, and font size
					to copy for the panel itself.
*/
private function init():void {	
  try {
  	
  	csxs = CSXSInterface.getInstance();						  	

	getVersionString();

	localizePanel();

	resetToDefaults();
	
	getCurrentSettings();
	
	updateUIFromCurrentSettings();
	
	updatePanelMenu();
	
	viewStack.selectedChild = mainView;

	var result:SyncRequestResult = csxs.getHostEnvironment();
   	if (SyncRequestResult.COMPLETE == result.status) {
		var hostData:HostEnvironment = result.data;
		var skinInfo:AppSkinInfo = hostData.appSkinInfo;
		StyleManager.getStyleDeclaration("global").setStyle("fontFamily", skinInfo.baseFontFamily);
		StyleManager.getStyleDeclaration("global").setStyle("fontSize", skinInfo.baseFontSize);
		setColors(skinInfo.panelBackgroundColor.color.rgb);
	}

	csxs.requestStateChange(StateChangeEvent.WINDOW_RESIZE, getGeometry());

	csxs.addEventListener(AppReskinEvent.APPLICATION_RESKIN, appReskinEvent);
	
	csxs.evalScript("PhotoshopPersistent");
			
	maybeShowHelp();
	
	csxs.evalScript("colourAssistant.turnOnOffMessages", showStepMessage.toString());
	
  }
  
  catch (errObject:Error) {
  		myError(errObject);
  }
	
}


private function localizePanel():void {
	strResetText = localize('$$$/ColourAssistant/Reset=Reset');
	strMessagesText = localize('$$$/ColourAssistant/TurnOff=Turn on/off all tutorial messages');
	strHelpText = localize('$$$/Actions/Enum/Help/Help=Help');
	strGoFlyText = localize("$$$/Actions/Enum/Help/ArtistsQuarter=The Artists' Quarter Textures Web Site");
	panelWidth = Number(localize('$$$/ColourAssistant/panelWidth=290'));
	panelHeight = Number(localize('$$$/ColourAssistant/panelHeight=525'));
	fontSize = Number(localize('$$$/ColourAssistant/fontSize=10'));
	arrowOffset = Number(localize('$$$/ColourAssistant/arrowOffset=122'));
}

/**
 * Function:	updateUIFromCurrentSettings
 * Description:	Fix up the ui because we just got new settings
 */
private function updateUIFromCurrentSettings():void {
	btn2.enabled = btn1.enabled = true;

	btn1.setStyle("icon", this["btn1Icn"]);
	btn1.setStyle("overIcon", this["btn1RolloverIcn"]);

	btn3.enabled =
	btn35.enabled = 
	btn4.enabled =
	btn5.enabled =
	btn6.enabled =
	btn7.enabled =
	btn8.enabled =
	btn9.enabled = false;
}	

private function resetToDefaults():void {
	try {
		enabledStep = 1;
	}	
	catch(errObject:Error) {
		myError(errObject);
	}
}

private function paramsToParams(inStep:Number):String {
	var s:String;
	s = "({ stepNumber:'" + inStep.toString() + "'";
	s += ", showHelpMessage:" + showHelpMessage.toString();
	s += ", showStepMessage:" + showStepMessage.toString();
	s += ", version:'1'";
	s += "})";
	s = encodeURIComponent(s);
	s = escape(s);
	return s;
}

/**
 * Function:		getCurrentSettings
 * Description:		Read in our parameters from the CSXS Preferencess
 */
private function getCurrentSettings():void {
	try {
		var result:SyncRequestResult;
		var version:Number = 0;
		var reqResult:SyncRequestResult = CSXSInterface.instance.evalScript("colourAssistant.retrievePreferences");
		if (SyncRequestResult.COMPLETE == reqResult.status && reqResult.data) {
			version = Number(reqResult.data.version.toString());
			showHelpMessage = reqResult.data.showHelpMessage.toString() == "true";
			showStepMessage = reqResult.data.showStepMessage.toString() == "true";
		}
	}
    catch(e:Error) { 
 		; // do nothing
	}
}

/**
 * Function:		saveCurrentSettings
 * Description:		Save off our settings for later use
 */
private function saveCurrentSettings(params:String):void {
	var reqResult:SyncRequestResult = CSXSInterface.instance.evalScript("colourAssistant.storePreferences", params);
	if (SyncRequestResult.COMPLETE == reqResult.status) {
		; // I hope that worked
  	}
}


			
/**
 * Function:        localize
 * Description:     Get localized zstring
 */
private function localize(str:String):String{
    try {
        var reqResult:SyncRequestResult = csxs.evalScript("colourAssistant.getZstring", escape(encodeURIComponent(str)));
        if (SyncRequestResult.COMPLETE == reqResult.status) {
			return decodeURIComponent(unescape(reqResult.data.zstring));
        }
    }
    catch (errObject:Error) {
        myError(errObject);
    }
    return "";
}

private function updatePanelMenu():void {
	try {

		var xmlMenu:XML = <Menu>
              <MenuItem Label="Reset"/>
              <MenuItem Label="Messages"/>
              <MenuItem Label="Help!"/>
              <MenuItem Label="GoFly!"/>
              <MenuItem Label="V1"/>
           	  </Menu>;
           	  
        var xmlIndex:Number = 0;
        xmlMenu.MenuItem[xmlIndex++].@Label = strResetText;
        xmlMenu.MenuItem[xmlIndex++].@Label = strMessagesText;
        xmlMenu.MenuItem[xmlIndex++].@Label = strHelpText;
        xmlMenu.MenuItem[xmlIndex++].@Label = strGoFlyText;
        xmlMenu.MenuItem[xmlIndex++].@Label = strVersionText;
     
		var result:SyncRequestResult = csxs.setPanelMenu(xmlMenu);
		csxs.addEventListener(MenuClickEvent.FLYOUT_MENU_CLICK, onMenuHandler);
	}

  	catch (errObject:Error) {
        myError(errObject);
  	}
}

/**
 * Try to pull the version string out of the jsx file so it is easier to modify. 
 */
private function getVersionString():void {
	try {
		var reqResult:SyncRequestResult = csxs.evalScript("colourAssistant.getVersion");
		if (SyncRequestResult.COMPLETE == reqResult.status) {
			strVersionText = reqResult.data.myVersion;
    	}
	}
	catch (errObject:Error) {
		myError(errObject);
	}
}

/**
 * Function:		maybeShowHelp
 * Description:		See if we have asked them to show the help video, we do this only once
 * 
 *                  showHelpMessage is saved immediately and read from preferences before calling
 */
private function maybeShowHelp():void {
	if (showHelpMessage) {
		showHelpMessage = false;
		var showIt:Boolean = myConfirm("$$$/ColourAssistant/wouldyou=Would you like to see the help video for Colour Assistant now?");
		if (showIt) {
			csxs.evalScript("colourAssistant.runHelp", "1");
		}
	}
}

private function goFly(inID:String):void {
	switch(inID) {
		case "1":
		default:
			csxs.evalScript("colourAssistant.goFly");
			break;
		case "2":
			csxs.evalScript("colourAssistant.runHelp", "2");
			break;
		case "3":
			csxs.evalScript("colourAssistant.runHelp", "3");
			break;
	}
}

private function onMenuHandler(inEvent:MenuClickEvent):void {
	try {
		var reqResult:SyncRequestResult;
		if (strResetText == inEvent.menuName) {
			resetToDefaults();
			updateUIFromCurrentSettings();
		} else if (strMessagesText == inEvent.menuName) {
			reqResult = csxs.evalScript("colourAssistant.turnOnOffMessages");
			showStepMessage = ! showStepMessage;
		} else if (strHelpText == inEvent.menuName) {
			reqResult = csxs.evalScript("colourAssistant.runHelp", "1");
		} else if (strGoFlyText == inEvent.menuName) {
			reqResult = csxs.evalScript("colourAssistant.goFly");
		} else {
			myAlert(inEvent.menuName);
		} 
	}
	catch(errObject:Error) {
		myError(errObject);
	}
}	

/**
 * Function:		myConfirm
 * Description:		Pop the ExtendScript confirm dialog with a question and return yes (true) or no (false
 */
private function myConfirm(msg:String):Boolean {
	try {
		var reqResult:SyncRequestResult = csxs.evalScript("colourAssistant.myConfirm", escape(encodeURIComponent(msg)));
		if (SyncRequestResult.COMPLETE == reqResult.status) {
			return reqResult.data.myConfirm == "true";
    	}
	}
    catch (errObject:Error) {
    	;
	}
	return false;
}

private function myAlert(msg:String):void {
	// Alert.show(msg, strAlertText, Alert.OK, Sprite(mx.core.Application.application));
	var reqResult:SyncRequestResult = csxs.evalScript("colourAssistant.myAlert", escape(encodeURIComponent(msg)));
}

private function myError(err:Error):void {
	if (showErrors)
		myAlert("$$$/private/WatermarkError=" + err.message + " " + err.errorID.toString() + " " + err.name);
}

// end ColourAssistant.as
