﻿/*
@@@BUILDINFO@@@ ColourAssistant.jsx 1.0.5  25-May-2013
*/
﻿
/**************************************************************************
	ADOBE SYSTEMS INCORPORATED
	 Copyright 2012 Adobe Systems Incorporated
	 All Rights Reserved.

	NOTICE:  Adobe permits you to use, modify, and distribute this file
	in accordance with the terms of the Adobe license agreement accompanying
	it.  If you have received this file from a source other than Adobe, then
	your use, modification, or distribution of it requires the prior written
	permission of Adobe.
**************************************************************************/


try {
	

///////////////////////////////////////////////////////////////////////////////
// GLOBALS
///////////////////////////////////////////////////////////////////////////////
var colourAssistant = new Object;

///////////////////////////////////////////////////////////////////////////////

colourAssistant.strVersion = "Version 1.0.5";

///////////////////////////////////////////////////////////////////////////////

colourAssistant.showAlerts = true; // use this for user alerts, should be true
colourAssistant.debugAlerts = false; // use this for debug purposes only, should be false
colourAssistant.extraDebug = false; // really really really debug it, should be false
colourAssistant.skipOilPaint = false; // use this for debug purposes only, should be false
colourAssistant.showTutorialMessages = true; // ship with this true
colourAssistant.deleteThisPattern = -1; // -1, I didn't create one


///////////////////////////////////////////////////////////////////////////////
// Function: runProcess
// Usage: Main processing routine called from the panel
// Input: number as string, tells me which step to run, 
//        111 is special case for a reset
// Return: <nothing>
///////////////////////////////////////////////////////////////////////////////
colourAssistant.runProcess = function( inParamsAsSource ) {
	try {
		
		var params = colourAssistant.paramsToParams( inParamsAsSource, 0 /* version */ );
		
		switch(params.stepNumber) {
			case "1":
				colourAssistant.openADocument();
				break;
			case "2":
				if (documents.length == 0)
					colourAssistant.openADocument();
				colourAssistant.prepareCanvasAndSketch();
				break;
			case "3":
				colourAssistant.showDarkSketch(false /* hide */);
				break;
			case "35":
				colourAssistant.showDarkSketch(true /* show */);
				break;
			case "4":
				colourAssistant.initialWashes();
				break;
			case "5":
				colourAssistant.finishIntermediate();
				break;
			case "6":
				colourAssistant.addSubtleDetail();
				break;
			case "7":
				colourAssistant.addStrongDetail();
				break;
			case "8":
				colourAssistant.addHighlightDetail();
				break;
			case "9":
				colourAssistant.finishStep();
				break;
			case "111":
				colourAssistant.resetThings();
				break;
		} // end switch
	} // end try
	catch(e) {
		if (colourAssistant.showAlerts || colourAssistant.debugAlerts) {
			alert(e + ":" + e.line); 
		}
	}
}



///////////////////////////////////////////////////////////////////////////////
// Function: paramsToParams
// Usage: Conver the encoded string that represents a JavaScript Object back
// into an object. All this is necessary to get non xml characters across the
// interface from ActionScript to JavaScript.
//        inParamsAsSource is the encoded string representing the object
//		  inVersion is 0 for 2.0.5 params and 1 for 2.0.6 params
// Return: JavaScript object for all the params from the panel
///////////////////////////////////////////////////////////////////////////////
colourAssistant.paramsToParams = function( inParamsAsSource, inVersion ) {

	var params = new Object();

	try {
		params = eval( decodeURIComponent( unescape( inParamsAsSource ) ) );
	}

	catch(e) { 
		if (colourAssistant.showAlerts) alert(e +" : " + e.line); 
	}
	
	return params;
}



///////////////////////////////////////////////////////////////////////////////
// Function: turnOnOffMessages
// Usage: Called from the panel
// Input: turn on or off flag that tells me to pop messages at the end of a 
//        step, if no value is given then toggle
// Return: <nothing>
///////////////////////////////////////////////////////////////////////////////
colourAssistant.turnOnOffMessages = function( inSetting ) {
	if (typeof inSetting == "undefined" ) {
		colourAssistant.showTutorialMessages = ! colourAssistant.showTutorialMessages;
		if (colourAssistant.showTutorialMessages)
			alert("Messages are now on.");
		else
			alert("Messages are now off.");
	} else {
		colourAssistant.showTutorialMessages = inSetting == "true"; // string to boolean
	}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
// The following routines are what transfer data in and out of the swf panel
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////
// Function: stringToXML
// Usage: Returns to the panel must be wrapped in XML syntax
// Input: inString string to wrap in XML
// Return: string in XML syntax
///////////////////////////////////////////////////////////////////////////////
colourAssistant.stringToXML = function(inString) {
    var s = '<object>';
    s += colourAssistant.propertyToXML(0, "error");
    s += colourAssistant.propertyToXML(inString, "message");
    s += '</object>';
    return s;
}



///////////////////////////////////////////////////////////////////////////////
// Function: errorToXML
// Usage: Returns to the panel must be wrapped in XML syntax
// Input: inError is an Error object
// Return: Error in XML syntax
///////////////////////////////////////////////////////////////////////////////
colourAssistant.errorToXML = function(inError) {
    var s = '<object>';
    s += colourAssistant.propertyToXML(inError.number, "error");
    s += colourAssistant.propertyToXML(inError.message, "message");
    s += colourAssistant.propertyToXML(inError.line, "line");
    s += colourAssistant.propertyToXML(inError.fileName, "fileName");
    s += '</object>';
    return s;
}



///////////////////////////////////////////////////////////////////////////////
// Function: propertyToXML
// Usage: Returns to the panel must be wrapped in XML syntax, helper routine
// Input: inProperty property string
//        inID property id
// Return: property wrapped in XML syntax for return value to the panel
///////////////////////////////////////////////////////////////////////////////
colourAssistant.propertyToXML = function(inProperty, inID) {
    var t = typeof inProperty;
    var s = '<property id="' + inID + '">';
    switch (t) {
        case "number":
            s += '<number>' + inProperty.toString() + '</number>';
            break;
        case "boolean":
            s += '<' + inProperty.toString() + '/>';
            break;
        case "string":
            s += '<string>' + inProperty.toString() + '</string>';
            break;
        // TODO figure this out
        case "object":
            //s += '<object>';
			//for (var i in inProperty) {
			//	s += propertyToXML(inProperty[i], i.toString());
			//}
			//s += '</object>';
            break;
        case "undefined":
            s += '<string>undefined</string>';
            break;
        default:
            if (colourAssistant.debugAlerts) alert('unknown type not supported: ' + t);
            break;
    }
    s += '</property>';
    return s;
}



///////////////////////////////////////////////////////////////////////////////
// Function: getZstring
// Usage: Called from the panel so we can get localized zstring
// Input: zstring string
// Return: XML describing the full path to the folder
///////////////////////////////////////////////////////////////////////////////
colourAssistant.getZstring = function(zstring) {
	var s = '<object>';
	s += colourAssistant.propertyToXML(escape(encodeURIComponent(localize(decodeURIComponent(unescape(zstring))))), "zstring");
	s += '</object>';
	return s;
}



///////////////////////////////////////////////////////////////////////////////
// Function: myAlert
// Usage: Called from the panel
// Input: Display a string via the ExtenScript alert 
//        step
// Return: <nothing>
///////////////////////////////////////////////////////////////////////////////
colourAssistant.myAlert = function(zstring) {
	alert(localize(decodeURIComponent(unescape(zstring))));
}



/////////////////////////////////////////////////////////////////////
// Function: goFly
// Input: <none>
// Return: <none> but hopefully a web browser got launched
/////////////////////////////////////////////////////////////////////
colourAssistant.goFly = function( ) {
	var s = "";
	try {
		
		s = "<HTML><HEAD><META HTTP-EQUIV=REFRESH CONTENT=";
		s += '"0; URL=';
		s += localize("$$$/ColourAssistant/url/helpmovie=http://www.theartistsquarter.com");
		s += ' ">';
		s += "</HEAD><BODY>";
		s += "<!---CENTER><BR><BR><b><i><span style='font-family:Arial'>";
		s += localize("$$$/ColourAssistant/str/redirect=redirecting to documentation...");
		s += "</span></i></b></center--->";
		s += "</BODY></HTML>";
		
		var helpFile = new File( Folder.temp.toString() + '/ColourAssistant.html' );
		if (helpFile.open('w')) {
			helpFile.write( s );
			helpFile.close();
			helpFile.execute();
			s = colourAssistant.stringToXML("Success");
		}
	}
	catch(e) { 
		if (colourAssistant.showAlerts) alert(e + " : " + e.line); 
	}
	return s;
}

///////////////////////////////////////////////////////////////////////////////
// Function: runHelp
// Usage: Called from the panel so we can run the help web page
// Input: we have three movies to play
// Return: XML describing the full path to the ColourAssistant file
///////////////////////////////////////////////////////////////////////////////
colourAssistant.runHelp = function (movieNumber) {
	var s = "";
	var m = "";
	try {
		switch (movieNumber) {
			case "1":
			default:
				m = "http://av.adobe.com/russellbrown/Watercolour_help.mp4";
				break;
			case "2":
				m = "http://www.russellbrown.com/watercolour/RB.html";
				break;
			case "3":
				m = "http://www.russellbrown.com/watercolour/TS.html";
				break;
		}
		s = "<HTML><HEAD><META HTTP-EQUIV=REFRESH CONTENT=";
		s += '"0; URL=';
		s += m;
		s += ' ">';
		s += "</HEAD><BODY>";
		s += "<!---CENTER><BR><BR><b><i><span style='font-family:Arial'>";
		s += "redirecting to documentation...</span></i></b></center--->";
		s += "</BODY></HTML>";

		var helpFile = new File( Folder.temp.toString() + '/colourAssistant.html' );
		if (helpFile.open('w')) {
			helpFile.write( s );
			helpFile.close();
			helpFile.execute();
			s = colourAssistant.stringToXML("Success");
		}
	}
	catch(e) { 
		if (colourAssistant.showAlerts) 
			alert(e + " : " + e.line); 
	}
	return s;
}



///////////////////////////////////////////////////////////////////////////////
// Function: myConfirm
// Usage: Routine called from the panel, pop the ExtendScript confirm dialog 
//        and return result to the panel
// Input: string that is escaped and decoded
// Return: xml for the answer from the dialog
///////////////////////////////////////////////////////////////////////////////
colourAssistant.myConfirm = function(inStr) {
	var result = confirm(localize(decodeURIComponent(unescape(inStr))));
	var s = '<object>';
	s += colourAssistant.propertyToXML(result.toString(), "myConfirm");
	s += '</object>';
	return s;
}


///////////////////////////////////////////////////////////////////////////////
// Function: getVersion
// Usage: Panel puts the version in the panel fly out menu
//        get it from here so we can quickly edit it
// Input: <nothing>
// Return: Official version string
///////////////////////////////////////////////////////////////////////////////
colourAssistant.getVersion = function() {
	var s = '<object>';
	s += colourAssistant.propertyToXML(colourAssistant.strVersion, "myVersion");
	s += '</object>';
	return s;
}



///////////////////////////////////////////////////////////////////////////////
// Function: openADocument
// Usage: Pop the Photoshop open dialog for the user to select a document
// Input: <nothing>
// Return: cancel or a new activeDocument
///////////////////////////////////////////////////////////////////////////////
colourAssistant.openADocument = function() {
	ErrStrs = {}; 
	ErrStrs.USER_CANCELLED=localize("$$$/ScriptingSupport/Error/UserCancelled=User cancelled the operation"); 
	try {
		var idOpn = charIDToTypeID( "Opn " ); 
		executeAction( idOpn, undefined, DialogModes.ALL );
	} 
	catch(e){
		if (e.toString().indexOf(ErrStrs.USER_CANCELLED)!=-1) {
			;
		} else {
			alert(localize("$$$/ScriptingSupport/Error/CommandNotAvailable=The command is currently not available"));
		}
	}
}



///////////////////////////////////////////////////////////////////////////////
// Function: prepareCanvasAndSketch
///////////////////////////////////////////////////////////////////////////////
colourAssistant.prepareCanvasAndSketch = function () {
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc52 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref44 = new ActionReference();
	var idmoveTool = stringIDToTypeID( "moveTool" );
	    ref44.putClass( idmoveTool );
	desc52.putReference( idnull, ref44 );
	var iddontRecord = stringIDToTypeID( "dontRecord" );
	desc52.putBoolean( iddontRecord, true );
	var idforceNotify = stringIDToTypeID( "forceNotify" );
	    desc52.putBoolean( idforceNotify, true );
	executeAction( idslct, desc52, DialogModes.NO );

	// =======================================================
	var idFltI = charIDToTypeID( "FltI" );
	executeAction( idFltI, undefined, DialogModes.NO );
	
	// =======================================================
	var idCnvM = charIDToTypeID( "CnvM" );
	var desc53 = new ActionDescriptor();
	var idT = charIDToTypeID( "T   " );
	var idRGBM = charIDToTypeID( "RGBM" );
	    desc53.putClass( idT, idRGBM );
	executeAction( idCnvM, desc53, DialogModes.NO );
	
	// =======================================================
	var idCnvM = charIDToTypeID( "CnvM" );
	var desc54 = new ActionDescriptor();
	var idDpth = charIDToTypeID( "Dpth" );
	desc54.putInteger( idDpth, 8 );
	var idMrge = charIDToTypeID( "Mrge" );
	    desc54.putBoolean( idMrge, false );
	executeAction( idCnvM, desc54, DialogModes.NO );
	
	// =======================================================
	var idthreecaathreefourthreefourcbsixsevenoneonedonebcfourthreezerozerosixzerobzeroaonethreedcfour = stringIDToTypeID( "3caa3434-cb67-11d1-bc43-0060b0a13dc4" );
	var desc55 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc55.putString( idMsge, "Fit Image action settings" );
	var idHght = charIDToTypeID( "Hght" );
	var idPxl = charIDToTypeID( "#Pxl" );
	desc55.putUnitDouble( idHght, idPxl, 2000.000000 );
	var idWdth = charIDToTypeID( "Wdth" );
	var idPxl = charIDToTypeID( "#Pxl" );
	desc55.putUnitDouble( idWdth, idPxl, 2000.000000 );
	var idlimit = stringIDToTypeID( "limit" );
	    desc55.putBoolean( idlimit, false );
	executeAction( idthreecaathreefourthreefourcbsixsevenoneonedonebcfourthreezerozerosixzerobzeroaonethreedcfour, desc55, DialogModes.NO );
	
	// =======================================================
	var idImgS = charIDToTypeID( "ImgS" );
	var desc56 = new ActionDescriptor();
	var idRslt = charIDToTypeID( "Rslt" );
	var idRsl = charIDToTypeID( "#Rsl" );
	    desc56.putUnitDouble( idRslt, idRsl, 300.000000 );
	executeAction( idImgS, desc56, DialogModes.NO );
	
	// =======================================================
	var idFltI = charIDToTypeID( "FltI" );
	executeAction( idFltI, undefined, DialogModes.NO );
	
	// =======================================================
	var idsurfaceBlur = stringIDToTypeID( "surfaceBlur" );
	var desc240 = new ActionDescriptor();
	var idRds = charIDToTypeID( "Rds " );
	var idPxl = charIDToTypeID( "#Pxl" );
	desc240.putUnitDouble( idRds, idPxl, 30.000000 );
	var idThsh = charIDToTypeID( "Thsh" );
	    desc240.putInteger( idThsh, 10 );
	executeAction( idsurfaceBlur, desc240, DialogModes.NO );
	
// =======================================================
	var idsetd = charIDToTypeID( "setd" );
  	var desc2 = new ActionDescriptor();
    	var idnull = charIDToTypeID( "null" );
        var ref1 = new ActionReference();
        var idLyr = charIDToTypeID( "Lyr " );
        var idBckg = charIDToTypeID( "Bckg" );
        ref1.putProperty( idLyr, idBckg );
    	desc2.putReference( idnull, ref1 );
    	var idT = charIDToTypeID( "T   " );
        var desc3 = new ActionDescriptor();
        var idNm = charIDToTypeID( "Nm  " );
        desc3.putString( idNm, "Background" );
        var idOpct = charIDToTypeID( "Opct" );
        var idPrc = charIDToTypeID( "#Prc" );
        desc3.putUnitDouble( idOpct, idPrc, 100.000000 );
        var idMd = charIDToTypeID( "Md  " );
        var idBlnM = charIDToTypeID( "BlnM" );
        var idNrml = charIDToTypeID( "Nrml" );
        desc3.putEnumerated( idMd, idBlnM, idNrml );
    	var idLyr = charIDToTypeID( "Lyr " );
    	desc2.putObject( idT, idLyr, desc3 );
	executeAction( idsetd, desc2, DialogModes.NO );

	// =======================================================
	var idDplc = charIDToTypeID( "Dplc" );
    var desc10 = new ActionDescriptor();
    var idnull = charIDToTypeID( "null" );
        var ref7 = new ActionReference();
        var idLyr = charIDToTypeID( "Lyr " );
        var idOrdn = charIDToTypeID( "Ordn" );
        var idTrgt = charIDToTypeID( "Trgt" );
        ref7.putEnumerated( idLyr, idOrdn, idTrgt );
    desc10.putReference( idnull, ref7 );
    var idNm = charIDToTypeID( "Nm  " );
    desc10.putString( idNm, "Background copy" );
    var idVrsn = charIDToTypeID( "Vrsn" );
    desc10.putInteger( idVrsn, 5 );
	executeAction( idDplc, desc10, DialogModes.NO );

	// =======================================================
	var idDplc = charIDToTypeID( "Dplc" );
    var desc11 = new ActionDescriptor();
    var idnull = charIDToTypeID( "null" );
        var ref8 = new ActionReference();
        var idLyr = charIDToTypeID( "Lyr " );
        var idOrdn = charIDToTypeID( "Ordn" );
        var idTrgt = charIDToTypeID( "Trgt" );
        ref8.putEnumerated( idLyr, idOrdn, idTrgt );
    desc11.putReference( idnull, ref8 );
    var idNm = charIDToTypeID( "Nm  " );
    desc11.putString( idNm, "Background copy 2" );
    var idVrsn = charIDToTypeID( "Vrsn" );
    desc11.putInteger( idVrsn, 5 );
	executeAction( idDplc, desc11, DialogModes.NO );

	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc59 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref47 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref47.putName( idLyr, "Background copy" );
	desc59.putReference( idnull, ref47 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc59.putBoolean( idMkVs, false );
	executeAction( idslct, desc59, DialogModes.NO );
	
	// =======================================================
	var idFl = charIDToTypeID( "Fl  " );
	var desc60 = new ActionDescriptor();
	var idUsng = charIDToTypeID( "Usng" );
	var idFlCn = charIDToTypeID( "FlCn" );
	var idWht = charIDToTypeID( "Wht " );
	desc60.putEnumerated( idUsng, idFlCn, idWht );
	var idOpct = charIDToTypeID( "Opct" );
	var idPrc = charIDToTypeID( "#Prc" );
	desc60.putUnitDouble( idOpct, idPrc, 100.000000 );
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idNrml = charIDToTypeID( "Nrml" );
	    desc60.putEnumerated( idMd, idBlnM, idNrml );
	executeAction( idFl, desc60, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc61 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref48 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref48.putEnumerated( idLyr, idOrdn, idTrgt );
	desc61.putReference( idnull, ref48 );
	var idT = charIDToTypeID( "T   " );
	var desc62 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc62.putString( idNm, "White Background" );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc61.putObject( idT, idLyr, desc62 );
	executeAction( idsetd, desc61, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc63 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref49 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref49.putName( idLyr, "Background copy 2" );
	desc63.putReference( idnull, ref49 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc63.putBoolean( idMkVs, false );
	executeAction( idslct, desc63, DialogModes.NO );
	
	// =======================================================
	var idDstt = charIDToTypeID( "Dstt" );
	executeAction( idDstt, undefined, DialogModes.NO );
	
	// =======================================================
	var idLvls = charIDToTypeID( "Lvls" );
	var desc64 = new ActionDescriptor();
	var idpresetKind = stringIDToTypeID( "presetKind" );
	var idpresetKindType = stringIDToTypeID( "presetKindType" );
	var idpresetKindCustom = stringIDToTypeID( "presetKindCustom" );
	desc64.putEnumerated( idpresetKind, idpresetKindType, idpresetKindCustom );
	var idAdjs = charIDToTypeID( "Adjs" );
	var list1 = new ActionList();
	    var desc65 = new ActionDescriptor();
	    var idChnl = charIDToTypeID( "Chnl" );
	var ref50 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idCmps = charIDToTypeID( "Cmps" );
	    ref50.putEnumerated( idChnl, idChnl, idCmps );
	desc65.putReference( idChnl, ref50 );
	var idInpt = charIDToTypeID( "Inpt" );
	    var list2 = new ActionList();
	    list2.putInteger( 25 );
	    list2.putInteger( 220 );
	desc65.putList( idInpt, list2 );
	var idGmm = charIDToTypeID( "Gmm " );
	    desc65.putDouble( idGmm, 1.050000 );
	var idLvlA = charIDToTypeID( "LvlA" );
	list1.putObject( idLvlA, desc65 );
	    var desc66 = new ActionDescriptor();
	    var idChnl = charIDToTypeID( "Chnl" );
	var ref51 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idRd = charIDToTypeID( "Rd  " );
	    ref51.putEnumerated( idChnl, idChnl, idRd );
	desc66.putReference( idChnl, ref51 );
	var idAuto = charIDToTypeID( "Auto" );
	    desc66.putBoolean( idAuto, true );
	var idLvlA = charIDToTypeID( "LvlA" );
	list1.putObject( idLvlA, desc66 );
	    var desc67 = new ActionDescriptor();
	    var idChnl = charIDToTypeID( "Chnl" );
	var ref52 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idGrn = charIDToTypeID( "Grn " );
	    ref52.putEnumerated( idChnl, idChnl, idGrn );
	desc67.putReference( idChnl, ref52 );
	var idAuto = charIDToTypeID( "Auto" );
	    desc67.putBoolean( idAuto, true );
	var idLvlA = charIDToTypeID( "LvlA" );
	list1.putObject( idLvlA, desc67 );
	    var desc68 = new ActionDescriptor();
	    var idChnl = charIDToTypeID( "Chnl" );
	var ref53 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idBl = charIDToTypeID( "Bl  " );
	    ref53.putEnumerated( idChnl, idChnl, idBl );
	desc68.putReference( idChnl, ref53 );
	var idAuto = charIDToTypeID( "Auto" );
	    desc68.putBoolean( idAuto, true );
	var idLvlA = charIDToTypeID( "LvlA" );
	        list1.putObject( idLvlA, desc68 );
	    desc64.putList( idAdjs, list1 );
	executeAction( idLvls, desc64, DialogModes.NO );
	
	// =======================================================
	var idPbPl = charIDToTypeID( "PbPl" );
	var desc69 = new ActionDescriptor();
	var idKnNm = charIDToTypeID( "KnNm" );
	desc69.putString( idKnNm, "Oil Paint" );
	var idGpuY = charIDToTypeID( "GpuY" );
	desc69.putBoolean( idGpuY, true );
	var idLIWy = charIDToTypeID( "LIWy" );
	desc69.putBoolean( idLIWy, true );
	var idFPth = charIDToTypeID( "FPth" );
	desc69.putString( idFPth, "1" );
	var idPNaa = charIDToTypeID( "PNaa" );
	desc69.putString( idPNaa, "Stylization" );
	var idPTaa = charIDToTypeID( "PTaa" );
	desc69.putInteger( idPTaa, 0 );
	var idPFaa = charIDToTypeID( "PFaa" );
	desc69.putDouble( idPFaa, 8.119000 );
	var idPNab = charIDToTypeID( "PNab" );
	desc69.putString( idPNab, "Cleanliness" );
	var idPTab = charIDToTypeID( "PTab" );
	desc69.putInteger( idPTab, 0 );
	var idPFab = charIDToTypeID( "PFab" );
	desc69.putDouble( idPFab, 7.250000 );
	var idPNac = charIDToTypeID( "PNac" );
	desc69.putString( idPNac, "BrushScale" );
	var idPTac = charIDToTypeID( "PTac" );
	desc69.putInteger( idPTac, 0 );
	var idPFac = charIDToTypeID( "PFac" );
	desc69.putDouble( idPFac, 0.100000 );
	var idPNad = charIDToTypeID( "PNad" );
	desc69.putString( idPNad, "MicroBrush" );
	var idPTad = charIDToTypeID( "PTad" );
	desc69.putInteger( idPTad, 0 );
	var idPFad = charIDToTypeID( "PFad" );
	desc69.putDouble( idPFad, 10.000000 );
	var idPNae = charIDToTypeID( "PNae" );
	desc69.putString( idPNae, "LightDirection" );
	var idPTae = charIDToTypeID( "PTae" );
	desc69.putInteger( idPTae, 0 );
	var idPFae = charIDToTypeID( "PFae" );
	desc69.putDouble( idPFae, 0.000000 );
	var idPNaf = charIDToTypeID( "PNaf" );
	desc69.putString( idPNaf, "Specularity" );
	var idPTaf = charIDToTypeID( "PTaf" );
	desc69.putInteger( idPTaf, 0 );
	var idPFaf = charIDToTypeID( "PFaf" );
	desc69.putDouble( idPFaf, 0.000000 );
	if ( ! colourAssistant.skipOilPaint)
		executeAction( idPbPl, desc69, DialogModes.NO );
	
	// =======================================================
	var idGEfc = charIDToTypeID( "GEfc" );
	var desc70 = new ActionDescriptor();
	var idGEfk = charIDToTypeID( "GEfk" );
	var idGEft = charIDToTypeID( "GEft" );
	var idGlwE = charIDToTypeID( "GlwE" );
	desc70.putEnumerated( idGEfk, idGEft, idGlwE );
	var idEdgW = charIDToTypeID( "EdgW" );
	desc70.putInteger( idEdgW, 1 );
	var idEdgB = charIDToTypeID( "EdgB" );
	desc70.putInteger( idEdgB, 19 );
	var idSmth = charIDToTypeID( "Smth" );
	    desc70.putInteger( idSmth, 15 );
	executeAction( idGEfc, desc70, DialogModes.NO );
	
	// =======================================================
	var idInvr = charIDToTypeID( "Invr" );
	executeAction( idInvr, undefined, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc71 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref54 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref54.putEnumerated( idLyr, idOrdn, idTrgt );
	desc71.putReference( idnull, ref54 );
	var idT = charIDToTypeID( "T   " );
	var desc72 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc72.putString( idNm, "Light Sketch" );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc71.putObject( idT, idLyr, desc72 );
	executeAction( idsetd, desc71, DialogModes.NO );
	
	// =======================================================
	var idDplc = charIDToTypeID( "Dplc" );
	var desc73 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref55 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref55.putEnumerated( idLyr, idOrdn, idTrgt );
	desc73.putReference( idnull, ref55 );
	var idVrsn = charIDToTypeID( "Vrsn" );
	    desc73.putInteger( idVrsn, 5 );
	executeAction( idDplc, desc73, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc74 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref56 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref56.putEnumerated( idLyr, idOrdn, idTrgt );
	desc74.putReference( idnull, ref56 );
	var idT = charIDToTypeID( "T   " );
	var desc75 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc75.putString( idNm, "Dark Sketch" );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc74.putObject( idT, idLyr, desc75 );
	executeAction( idsetd, desc74, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc76 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref57 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref57.putName( idLyr, "Light Sketch" );
	desc76.putReference( idnull, ref57 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc76.putBoolean( idMkVs, false );
	executeAction( idslct, desc76, DialogModes.NO );
	
	// =======================================================
	var idLvls = charIDToTypeID( "Lvls" );
	var desc77 = new ActionDescriptor();
	var idpresetKind = stringIDToTypeID( "presetKind" );
	var idpresetKindType = stringIDToTypeID( "presetKindType" );
	var idpresetKindCustom = stringIDToTypeID( "presetKindCustom" );
	desc77.putEnumerated( idpresetKind, idpresetKindType, idpresetKindCustom );
	var idAdjs = charIDToTypeID( "Adjs" );
	var list3 = new ActionList();
	    var desc78 = new ActionDescriptor();
	    var idChnl = charIDToTypeID( "Chnl" );
	var ref58 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idCmps = charIDToTypeID( "Cmps" );
	    ref58.putEnumerated( idChnl, idChnl, idCmps );
	desc78.putReference( idChnl, ref58 );
	var idInpt = charIDToTypeID( "Inpt" );
	    var list4 = new ActionList();
	    list4.putInteger( 0 );
	    list4.putInteger( 228 );
	desc78.putList( idInpt, list4 );
	var idGmm = charIDToTypeID( "Gmm " );
	    desc78.putDouble( idGmm, 1.120000 );
	var idLvlA = charIDToTypeID( "LvlA" );
	        list3.putObject( idLvlA, desc78 );
	    desc77.putList( idAdjs, list3 );
	executeAction( idLvls, desc77, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc79 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref59 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref59.putEnumerated( idLyr, idOrdn, idTrgt );
	desc79.putReference( idnull, ref59 );
	var idT = charIDToTypeID( "T   " );
	var desc80 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc80.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc79.putObject( idT, idLyr, desc80 );
	executeAction( idsetd, desc79, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc81 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref60 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref60.putEnumerated( idLyr, idOrdn, idTrgt );
	desc81.putReference( idnull, ref60 );
	var idT = charIDToTypeID( "T   " );
	var desc82 = new ActionDescriptor();
	var idOpct = charIDToTypeID( "Opct" );
	var idPrc = charIDToTypeID( "#Prc" );
	    desc82.putUnitDouble( idOpct, idPrc, 50.000000 );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc81.putObject( idT, idLyr, desc82 );
	executeAction( idsetd, desc81, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc83 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref61 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref61.putName( idLyr, "Dark Sketch" );
	desc83.putReference( idnull, ref61 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc83.putBoolean( idMkVs, false );
	executeAction( idslct, desc83, DialogModes.NO );
	
	// =======================================================
	var idLvls = charIDToTypeID( "Lvls" );
	var desc84 = new ActionDescriptor();
	var idpresetKind = stringIDToTypeID( "presetKind" );
	var idpresetKindType = stringIDToTypeID( "presetKindType" );
	var idpresetKindCustom = stringIDToTypeID( "presetKindCustom" );
	desc84.putEnumerated( idpresetKind, idpresetKindType, idpresetKindCustom );
	var idAdjs = charIDToTypeID( "Adjs" );
	var list5 = new ActionList();
	    var desc85 = new ActionDescriptor();
	    var idChnl = charIDToTypeID( "Chnl" );
	var ref62 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idCmps = charIDToTypeID( "Cmps" );
	    ref62.putEnumerated( idChnl, idChnl, idCmps );
	desc85.putReference( idChnl, ref62 );
	var idInpt = charIDToTypeID( "Inpt" );
	    var list6 = new ActionList();
	    list6.putInteger( 23 );
	    list6.putInteger( 250 );
	desc85.putList( idInpt, list6 );
	var idGmm = charIDToTypeID( "Gmm " );
	    desc85.putDouble( idGmm, 1.830000 );
	var idLvlA = charIDToTypeID( "LvlA" );
	        list5.putObject( idLvlA, desc85 );
	    desc84.putList( idAdjs, list5 );
	executeAction( idLvls, desc84, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc86 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref63 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref63.putEnumerated( idLyr, idOrdn, idTrgt );
	desc86.putReference( idnull, ref63 );
	var idT = charIDToTypeID( "T   " );
	var desc87 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc87.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc86.putObject( idT, idLyr, desc87 );
	executeAction( idsetd, desc86, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc88 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref64 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref64.putEnumerated( idLyr, idOrdn, idTrgt );
	desc88.putReference( idnull, ref64 );
	var idT = charIDToTypeID( "T   " );
	var desc89 = new ActionDescriptor();
	var idOpct = charIDToTypeID( "Opct" );
	var idPrc = charIDToTypeID( "#Prc" );
	    desc89.putUnitDouble( idOpct, idPrc, 60.000000 );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc88.putObject( idT, idLyr, desc89 );
	executeAction( idsetd, desc88, DialogModes.NO );
	
	// =======================================================
	var idHd = charIDToTypeID( "Hd  " );
	var desc90 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var list7 = new ActionList();
	    var ref65 = new ActionReference();
	    var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	            ref65.putEnumerated( idLyr, idOrdn, idTrgt );
	        list7.putReference( ref65 );
	    desc90.putList( idnull, list7 );
	executeAction( idHd, desc90, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc91 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref66 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref66.putName( idLyr, "Background" );
	desc91.putReference( idnull, ref66 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc91.putBoolean( idMkVs, false );
	executeAction( idslct, desc91, DialogModes.NO );
	
	// =======================================================
	var idDplc = charIDToTypeID( "Dplc" );
	var desc92 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref67 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref67.putEnumerated( idLyr, idOrdn, idTrgt );
	desc92.putReference( idnull, ref67 );
	var idVrsn = charIDToTypeID( "Vrsn" );
	    desc92.putInteger( idVrsn, 5 );
	executeAction( idDplc, desc92, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc93 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref68 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idFrwr = charIDToTypeID( "Frwr" );
	    ref68.putEnumerated( idLyr, idOrdn, idFrwr );
	desc93.putReference( idnull, ref68 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc93.putBoolean( idMkVs, false );
	executeAction( idslct, desc93, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc94 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref69 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref69.putEnumerated( idLyr, idOrdn, idBckw );
	desc94.putReference( idnull, ref69 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc94.putBoolean( idMkVs, false );
	executeAction( idslct, desc94, DialogModes.NO );
	
	// =======================================================
	var idmove = charIDToTypeID( "move" );
	var desc95 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref70 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref70.putEnumerated( idLyr, idOrdn, idTrgt );
	desc95.putReference( idnull, ref70 );
	var idT = charIDToTypeID( "T   " );
	var ref71 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idNxt = charIDToTypeID( "Nxt " );
	        ref71.putEnumerated( idLyr, idOrdn, idNxt );
	    desc95.putReference( idT, ref71 );
	executeAction( idmove, desc95, DialogModes.NO );
	
	// =======================================================
	var idmove = charIDToTypeID( "move" );
	var desc96 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref72 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref72.putEnumerated( idLyr, idOrdn, idTrgt );
	desc96.putReference( idnull, ref72 );
	var idT = charIDToTypeID( "T   " );
	var ref73 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idNxt = charIDToTypeID( "Nxt " );
	        ref73.putEnumerated( idLyr, idOrdn, idNxt );
	    desc96.putReference( idT, ref73 );
	executeAction( idmove, desc96, DialogModes.NO );
	
	// =======================================================
	var idmove = charIDToTypeID( "move" );
	var desc97 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref74 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref74.putEnumerated( idLyr, idOrdn, idTrgt );
	desc97.putReference( idnull, ref74 );
	var idT = charIDToTypeID( "T   " );
	var ref75 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idNxt = charIDToTypeID( "Nxt " );
	        ref75.putEnumerated( idLyr, idOrdn, idNxt );
	    desc97.putReference( idT, ref75 );
	executeAction( idmove, desc97, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc98 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref76 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idfsel = charIDToTypeID( "fsel" );
	    ref76.putProperty( idChnl, idfsel );
	desc98.putReference( idnull, ref76 );
	var idT = charIDToTypeID( "T   " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idAl = charIDToTypeID( "Al  " );
	    desc98.putEnumerated( idT, idOrdn, idAl );
	executeAction( idsetd, desc98, DialogModes.NO );
	
	// =======================================================
	var classPattern = charIDToTypeID('PttR');
	var classPatternPreset = charIDToTypeID('Ptrn');
	if ( ! colourAssistant.findPresetByName('bockingford_not_', classPattern) ) {
		colourAssistant.loadPreset(app.path + '/Presets/Patterns/Watercolour Patterns.pat', classPatternPreset);
	}
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc99 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref77 = new ActionReference();
	var idPtrn = charIDToTypeID( "Ptrn" );
	    ref77.putClass( idPtrn );
	desc99.putReference( idnull, ref77 );
	var idUsng = charIDToTypeID( "Usng" );
	var ref78 = new ActionReference();
	var idPrpr = charIDToTypeID( "Prpr" );
	var idfsel = charIDToTypeID( "fsel" );
	ref78.putProperty( idPrpr, idfsel );
	var idDcmn = charIDToTypeID( "Dcmn" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref78.putEnumerated( idDcmn, idOrdn, idTrgt );
	desc99.putReference( idUsng, ref78 );
	var idNm = charIDToTypeID( "Nm  " );
	desc99.putString( idNm, "Watercolour Pattern" );
	executeAction( idMk, desc99, DialogModes.NO );
	
	// =======================================================
	var classPattern = charIDToTypeID('PttR');
	colourAssistant.deleteThisPattern = colourAssistant.howManyPresets( classPattern );
	
	// =======================================================
	var idDlt = charIDToTypeID( "Dlt " );
	var desc100 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref79 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	        ref79.putEnumerated( idLyr, idOrdn, idTrgt );
	    desc100.putReference( idnull, ref79 );
	executeAction( idDlt, desc100, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc101 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref80 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idfsel = charIDToTypeID( "fsel" );
	    ref80.putProperty( idChnl, idfsel );
	desc101.putReference( idnull, ref80 );
	var idT = charIDToTypeID( "T   " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idNone = charIDToTypeID( "None" );
	    desc101.putEnumerated( idT, idOrdn, idNone );
	executeAction( idsetd, desc101, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc102 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref81 = new ActionReference();
	var idcontentLayer = stringIDToTypeID( "contentLayer" );
	    ref81.putClass( idcontentLayer );
	desc102.putReference( idnull, ref81 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc103 = new ActionDescriptor();
	var idType = charIDToTypeID( "Type" );
	var desc104 = new ActionDescriptor();
	var idPtrn = charIDToTypeID( "Ptrn" );
	var desc105 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc105.putString( idNm, "bockingford_not_" );
	var idIdnt = charIDToTypeID( "Idnt" );
	desc105.putString( idIdnt, "703fe2f1-3ed3-11e1-a80e-ea2062108fa6" );
	var idPtrn = charIDToTypeID( "Ptrn" );
	    desc104.putObject( idPtrn, idPtrn, desc105 );
	var idpatternLayer = stringIDToTypeID( "patternLayer" );
	    desc103.putObject( idType, idpatternLayer, desc104 );
	var idcontentLayer = stringIDToTypeID( "contentLayer" );
	    desc102.putObject( idUsng, idcontentLayer, desc103 );
	executeAction( idMk, desc102, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc7 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	   var ref3 = new ActionReference();
	   var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	ref3.putEnumerated( idLyr, idOrdn, idTrgt );
	desc7.putReference( idnull, ref3 );
	var idT = charIDToTypeID( "T   " );
	var desc8 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc8.putString( idNm, "Pattern Fill 1" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc7.putObject( idT, idLyr, desc8 );
	executeAction( idsetd, desc7, DialogModes.NO );

	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc106 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref82 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref82.putEnumerated( idLyr, idOrdn, idTrgt );
	desc106.putReference( idnull, ref82 );
	var idT = charIDToTypeID( "T   " );
	var desc107 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc107.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc106.putObject( idT, idLyr, desc107 );
	executeAction( idsetd, desc106, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc108 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref83 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref83.putEnumerated( idLyr, idOrdn, idTrgt );
	desc108.putReference( idnull, ref83 );
	var idT = charIDToTypeID( "T   " );
	var desc109 = new ActionDescriptor();
	var idOpct = charIDToTypeID( "Opct" );
	var idPrc = charIDToTypeID( "#Prc" );
	    desc109.putUnitDouble( idOpct, idPrc, 31.000000 );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc108.putObject( idT, idLyr, desc109 );
	executeAction( idsetd, desc108, DialogModes.NO );
	
	// =======================================================
	var idDplc = charIDToTypeID( "Dplc" );
	var desc110 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref84 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref84.putEnumerated( idLyr, idOrdn, idTrgt );
	desc110.putReference( idnull, ref84 );
	var idVrsn = charIDToTypeID( "Vrsn" );
	    desc110.putInteger( idVrsn, 5 );
	executeAction( idDplc, desc110, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc111 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref85 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref85.putEnumerated( idLyr, idOrdn, idTrgt );
	desc111.putReference( idnull, ref85 );
	var idT = charIDToTypeID( "T   " );
	var desc112 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc112.putString( idNm, "Pattern Fill 2" );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc111.putObject( idT, idLyr, desc112 );
	executeAction( idsetd, desc111, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc113 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref86 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref86.putEnumerated( idLyr, idOrdn, idTrgt );
	desc113.putReference( idnull, ref86 );
	var idT = charIDToTypeID( "T   " );
	var desc114 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idOvrl = charIDToTypeID( "Ovrl" );
	    desc114.putEnumerated( idMd, idBlnM, idOvrl );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc113.putObject( idT, idLyr, desc114 );
	executeAction( idsetd, desc113, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc115 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref87 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref87.putName( idLyr, "Pattern Fill 1" );
	desc115.putReference( idnull, ref87 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelectionContinuous = stringIDToTypeID( "addToSelectionContinuous" );
	desc115.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelectionContinuous );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc115.putBoolean( idMkVs, false );
	executeAction( idslct, desc115, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc116 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref88 = new ActionReference();
	var idlayerSection = stringIDToTypeID( "layerSection" );
	    ref88.putClass( idlayerSection );
	desc116.putReference( idnull, ref88 );
	var idFrom = charIDToTypeID( "From" );
	var ref89 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref89.putEnumerated( idLyr, idOrdn, idTrgt );
	desc116.putReference( idFrom, ref89 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc117 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc117.putString( idNm, "Pattern" );
	var idlayerSection = stringIDToTypeID( "layerSection" );
	    desc116.putObject( idUsng, idlayerSection, desc117 );
	executeAction( idMk, desc116, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc118 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref90 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref90.putName( idLyr, "Dark Sketch" );
	desc118.putReference( idnull, ref90 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc118.putBoolean( idMkVs, false );
	executeAction( idslct, desc118, DialogModes.NO );
	
	// =======================================================
	var idShw = charIDToTypeID( "Shw " );
	var desc119 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var list8 = new ActionList();
	    var ref91 = new ActionReference();
	    var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	            ref91.putEnumerated( idLyr, idOrdn, idTrgt );
	        list8.putReference( ref91 );
	    desc119.putList( idnull, list8 );
	executeAction( idShw, desc119, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc120 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref92 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref92.putEnumerated( idLyr, idOrdn, idTrgt );
	desc120.putReference( idnull, ref92 );
	var idT = charIDToTypeID( "T   " );
	var desc121 = new ActionDescriptor();
	var idlayerLocking = stringIDToTypeID( "layerLocking" );
	var desc122 = new ActionDescriptor();
	var idprotectAll = stringIDToTypeID( "protectAll" );
	    desc122.putBoolean( idprotectAll, true );
	var idlayerLocking = stringIDToTypeID( "layerLocking" );
	    desc121.putObject( idlayerLocking, idlayerLocking, desc122 );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc120.putObject( idT, idLyr, desc121 );
	executeAction( idsetd, desc120, DialogModes.NO );
	
	// =======================================================
	var idHd = charIDToTypeID( "Hd  " );
	var desc123 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var list9 = new ActionList();
	    var ref93 = new ActionReference();
	    var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	            ref93.putEnumerated( idLyr, idOrdn, idTrgt );
	        list9.putReference( ref93 );
	    desc123.putList( idnull, list9 );
	executeAction( idHd, desc123, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc124 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref94 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref94.putName( idLyr, "Light Sketch" );
	desc124.putReference( idnull, ref94 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc124.putBoolean( idMkVs, false );
	executeAction( idslct, desc124, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc125 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref95 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref95.putEnumerated( idLyr, idOrdn, idTrgt );
	desc125.putReference( idnull, ref95 );
	var idT = charIDToTypeID( "T   " );
	var desc126 = new ActionDescriptor();
	var idlayerLocking = stringIDToTypeID( "layerLocking" );
	var desc127 = new ActionDescriptor();
	var idprotectAll = stringIDToTypeID( "protectAll" );
	    desc127.putBoolean( idprotectAll, true );
	var idlayerLocking = stringIDToTypeID( "layerLocking" );
	    desc126.putObject( idlayerLocking, idlayerLocking, desc127 );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc125.putObject( idT, idLyr, desc126 );
	executeAction( idsetd, desc125, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref10 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref10.putName( idLyr, "Background" );
	desc11.putReference( idnull, ref10 );
	var idMkVs = charIDToTypeID( "MkVs" );
		desc11.putBoolean( idMkVs, false );
	executeAction( idslct, desc11, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	 var desc2 = new ActionDescriptor();
		var idnull = charIDToTypeID( "null" );
	var ref1 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref1.putName( idLyr, "White Background" );
	desc2.putReference( idnull, ref1 );
	var idMkVs = charIDToTypeID( "MkVs" );
		desc2.putBoolean( idMkVs, false );
	executeAction( idslct, desc2, DialogModes.NO );
	
	// =======================================================
	var idmove = charIDToTypeID( "move" );
	var desc3 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref2 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	ref2.putEnumerated( idLyr, idOrdn, idTrgt );
	desc3.putReference( idnull, ref2 );
	var idT = charIDToTypeID( "T   " );
	var ref3 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idPrvs = charIDToTypeID( "Prvs" );
	    ref3.putEnumerated( idLyr, idOrdn, idPrvs );
		desc3.putReference( idT, ref3 );
	executeAction( idmove, desc3, DialogModes.NO );
	
	// =======================================================
	var idmove = charIDToTypeID( "move" );
	var desc4 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref4 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	ref4.putEnumerated( idLyr, idOrdn, idTrgt );
	desc4.putReference( idnull, ref4 );
	var idT = charIDToTypeID( "T   " );
	var ref5 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idPrvs = charIDToTypeID( "Prvs" );
	    ref5.putEnumerated( idLyr, idOrdn, idPrvs );
		desc4.putReference( idT, ref5 );
	executeAction( idmove, desc4, DialogModes.NO );
	
	// =======================================================
	var idmove = charIDToTypeID( "move" );
	var desc3 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref1 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	ref1.putEnumerated( idLyr, idOrdn, idTrgt );
	desc3.putReference( idnull, ref1 );
	var idT = charIDToTypeID( "T   " );
	var ref2 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idNxt = charIDToTypeID( "Nxt " );
	    ref2.putEnumerated( idLyr, idOrdn, idNxt );
		desc3.putReference( idT, ref2 );
	executeAction( idmove, desc3, DialogModes.NO );

	// =======================================================
	var idStop = charIDToTypeID( "Stop" );
	var desc239 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc239.putString( idMsge, "Select a light or dark sketch in step #3 that best suits your image style." );
	var idCntn = charIDToTypeID( "Cntn" );
	desc239.putBoolean( idCntn, true );
	
	if (colourAssistant.showTutorialMessages)
		executeAction( idStop, desc239, DialogModes.ALL );

}



///////////////////////////////////////////////////////////////////////////////
// Function: openADocument
// Usage: One of the steps from Listener recorded by the Dr.
//        some logic added to manage the preset files used
// Input: <nothing>
// Return: <nothing> but the document sure did change!!!!
///////////////////////////////////////////////////////////////////////////////
colourAssistant.showDarkSketch = function (inShow) {
	activeDocument.artLayers["Dark Sketch"].visible = inShow;
}

colourAssistant.initialWashes = function () {
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc136 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref103 = new ActionReference();
	var idPaTl = charIDToTypeID( "PaTl" );
	        ref103.putClass( idPaTl );
	    desc136.putReference( idnull, ref103 );
	executeAction( idslct, desc136, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc137 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref104 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref104.putName( idLyr, "White Background" );
	desc137.putReference( idnull, ref104 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc137.putBoolean( idMkVs, false );
	executeAction( idslct, desc137, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc138 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref105 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	    ref105.putClass( idLyr );
	desc138.putReference( idnull, ref105 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc139 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc139.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc138.putObject( idUsng, idLyr, desc139 );
	executeAction( idMk, desc138, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
	desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Layer_1" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );

	// =======================================================
	var classTool = stringIDToTypeID('toolPreset');
	if ( ! colourAssistant.findPresetByName('tim basic wash', classTool) ) {
		colourAssistant.loadPreset(app.path + '/Presets/Tools/Watercolour Presets.tpl', classTool);
	}
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc140 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref106 = new ActionReference();
	var idtoolPreset = stringIDToTypeID( "toolPreset" );
	ref106.putName( idtoolPreset, "tim basic wash" );
	    desc140.putReference( idnull, ref106 );
	executeAction( idslct, desc140, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc141 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref107 = new ActionReference();
	var idBrsh = charIDToTypeID( "Brsh" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref107.putEnumerated( idBrsh, idOrdn, idTrgt );
	desc141.putReference( idnull, ref107 );
	var idT = charIDToTypeID( "T   " );
	var desc142 = new ActionDescriptor();
	var idmasterDiameter = stringIDToTypeID( "masterDiameter" );
	var idPxl = charIDToTypeID( "#Pxl" );
	    desc142.putUnitDouble( idmasterDiameter, idPxl, 400.000000 );
	var idBrsh = charIDToTypeID( "Brsh" );
	    desc141.putObject( idT, idBrsh, desc142 );
	executeAction( idsetd, desc141, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc143 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref108 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	    ref108.putClass( idAdjL );
	desc143.putReference( idnull, ref108 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc144 = new ActionDescriptor();
	var idGrup = charIDToTypeID( "Grup" );
	desc144.putBoolean( idGrup, true );
	var idType = charIDToTypeID( "Type" );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc144.putClass( idType, idvibrance );
	var idAdjL = charIDToTypeID( "AdjL" );
	    desc143.putObject( idUsng, idAdjL, desc144 );
	executeAction( idMk, desc143, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc145 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref109 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref109.putEnumerated( idAdjL, idOrdn, idTrgt );
	desc145.putReference( idnull, ref109 );
	var idT = charIDToTypeID( "T   " );
	var desc146 = new ActionDescriptor();
	var idvibrance = stringIDToTypeID( "vibrance" );
	desc146.putInteger( idvibrance, 65 );
	var idStrt = charIDToTypeID( "Strt" );
	    desc146.putInteger( idStrt, 63 );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc145.putObject( idT, idvibrance, desc146 );
	executeAction( idsetd, desc145, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
		desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Vibrance_1" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc147 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref110 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref110.putName( idLyr, "Layer_1" );
	desc147.putReference( idnull, ref110 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc147.putBoolean( idMkVs, false );
	executeAction( idslct, desc147, DialogModes.NO );
	
	// =======================================================
	var idStop = charIDToTypeID( "Stop" );
	var desc239 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc239.putString( idMsge, "From the Pattern Picker up in the Option bar above, choose the watercolour pattern for your painting. It will be the last pattern in your current Pattern Picker set. Then use the current brush at this medium size to very loosely block in the first layer of the painting." );
	var idCntn = charIDToTypeID( "Cntn" );
	desc239.putBoolean( idCntn, true );

	if (colourAssistant.showTutorialMessages)
		executeAction( idStop, desc239, DialogModes.ALL );

}



///////////////////////////////////////////////////////////////////////////////
// Function: finishIntermediate
///////////////////////////////////////////////////////////////////////////////
colourAssistant.finishIntermediate = function () {
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc158 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref116 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref116.putName( idLyr, "Vibrance_1" );
	desc158.putReference( idnull, ref116 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc158.putBoolean( idMkVs, false );
	executeAction( idslct, desc158, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc159 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref117 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	    ref117.putClass( idLyr );
	desc159.putReference( idnull, ref117 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc160 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc160.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc159.putObject( idUsng, idLyr, desc160 );
	executeAction( idMk, desc159, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
	desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Layer_2" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );

	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc161 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref118 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	    ref118.putClass( idAdjL );
	desc161.putReference( idnull, ref118 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc162 = new ActionDescriptor();
	var idGrup = charIDToTypeID( "Grup" );
	desc162.putBoolean( idGrup, true );
	var idType = charIDToTypeID( "Type" );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc162.putClass( idType, idvibrance );
	var idAdjL = charIDToTypeID( "AdjL" );
	    desc161.putObject( idUsng, idAdjL, desc162 );
	executeAction( idMk, desc161, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
	desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Vibrance_2" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );

	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc163 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref119 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idRGB = charIDToTypeID( "RGB " );
	    ref119.putEnumerated( idChnl, idChnl, idRGB );
	desc163.putReference( idnull, ref119 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc163.putBoolean( idMkVs, false );
	executeAction( idslct, desc163, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc164 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref120 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref120.putEnumerated( idAdjL, idOrdn, idTrgt );
	desc164.putReference( idnull, ref120 );
	var idT = charIDToTypeID( "T   " );
	var desc165 = new ActionDescriptor();
	var idvibrance = stringIDToTypeID( "vibrance" );
	desc165.putInteger( idvibrance, 83 );
	var idStrt = charIDToTypeID( "Strt" );
	    desc165.putInteger( idStrt, 67 );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc164.putObject( idT, idvibrance, desc165 );
	executeAction( idsetd, desc164, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc166 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref121 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref121.putEnumerated( idLyr, idOrdn, idTrgt );
	desc166.putReference( idnull, ref121 );
	var idT = charIDToTypeID( "T   " );
	var desc167 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc167.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc166.putObject( idT, idLyr, desc167 );
	executeAction( idsetd, desc166, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc168 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref122 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref122.putName( idLyr, "Layer_2" );
	desc168.putReference( idnull, ref122 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc168.putBoolean( idMkVs, false );
	executeAction( idslct, desc168, DialogModes.NO );
	
	// =======================================================
	var classTool = stringIDToTypeID('toolPreset');
	if ( ! colourAssistant.findPresetByName('tim basic wash', classTool) ) {
		colourAssistant.loadPreset(app.path + '/Presets/Tools/Watercolour Presets.tpl', classTool);
	}
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc169 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref123 = new ActionReference();
	var idtoolPreset = stringIDToTypeID( "toolPreset" );
	ref123.putName( idtoolPreset, "tim basic wash" );
	    desc169.putReference( idnull, ref123 );
	executeAction( idslct, desc169, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc170 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref124 = new ActionReference();
	var idBrsh = charIDToTypeID( "Brsh" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref124.putEnumerated( idBrsh, idOrdn, idTrgt );
	desc170.putReference( idnull, ref124 );
	var idT = charIDToTypeID( "T   " );
	var desc171 = new ActionDescriptor();
	var idmasterDiameter = stringIDToTypeID( "masterDiameter" );
	var idPxl = charIDToTypeID( "#Pxl" );
	    desc171.putUnitDouble( idmasterDiameter, idPxl, 250.000000 );
	var idBrsh = charIDToTypeID( "Brsh" );
	    desc170.putObject( idT, idBrsh, desc171 );
	executeAction( idsetd, desc170, DialogModes.NO );
	
	// =======================================================
	var idStop = charIDToTypeID( "Stop" );
	var desc239 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc239.putString( idMsge, "On this second layer, use the current brush at this slightly smaller size to intensify and refine the most important areas in the scene, building tone and colour a little more." );
	var idCntn = charIDToTypeID( "Cntn" );
	desc239.putBoolean( idCntn, true );

	if (colourAssistant.showTutorialMessages)
		executeAction( idStop, desc239, DialogModes.ALL );

}



///////////////////////////////////////////////////////////////////////////////
// Function: addSubtleDetail
///////////////////////////////////////////////////////////////////////////////
colourAssistant.addSubtleDetail = function() {
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc172 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref125 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref125.putName( idLyr, "Vibrance_2" );
	desc172.putReference( idnull, ref125 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc172.putBoolean( idMkVs, false );
	executeAction( idslct, desc172, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc173 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref126 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	    ref126.putClass( idLyr );
	desc173.putReference( idnull, ref126 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc174 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc174.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc173.putObject( idUsng, idLyr, desc174 );
	executeAction( idMk, desc173, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
	desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Layer_3" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc175 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref127 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	    ref127.putClass( idAdjL );
	desc175.putReference( idnull, ref127 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc176 = new ActionDescriptor();
	var idGrup = charIDToTypeID( "Grup" );
	desc176.putBoolean( idGrup, true );
	var idType = charIDToTypeID( "Type" );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc176.putClass( idType, idvibrance );
	var idAdjL = charIDToTypeID( "AdjL" );
	    desc175.putObject( idUsng, idAdjL, desc176 );
	executeAction( idMk, desc175, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
	desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Vibrance_3" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );

	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc177 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref128 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idRGB = charIDToTypeID( "RGB " );
	    ref128.putEnumerated( idChnl, idChnl, idRGB );
	desc177.putReference( idnull, ref128 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc177.putBoolean( idMkVs, false );
	executeAction( idslct, desc177, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc178 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref129 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref129.putEnumerated( idAdjL, idOrdn, idTrgt );
	desc178.putReference( idnull, ref129 );
	var idT = charIDToTypeID( "T   " );
	var desc179 = new ActionDescriptor();
	var idvibrance = stringIDToTypeID( "vibrance" );
	desc179.putInteger( idvibrance, 83 );
	var idStrt = charIDToTypeID( "Strt" );
	    desc179.putInteger( idStrt, 61 );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc178.putObject( idT, idvibrance, desc179 );
	executeAction( idsetd, desc178, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc180 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref130 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref130.putName( idLyr, "Layer_3" );
	desc180.putReference( idnull, ref130 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc180.putBoolean( idMkVs, false );
	executeAction( idslct, desc180, DialogModes.NO );
	
	// =======================================================
	var classTool = stringIDToTypeID('toolPreset');
	if ( ! colourAssistant.findPresetByName('tim basic detail', classTool) ) {
		colourAssistant.loadPreset(app.path + '/Presets/Tools/Watercolour Presets.tpl', classTool);
	}
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc181 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref131 = new ActionReference();
	var idtoolPreset = stringIDToTypeID( "toolPreset" );
	ref131.putName( idtoolPreset, "tim basic detail" );
	    desc181.putReference( idnull, ref131 );
	executeAction( idslct, desc181, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc182 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref132 = new ActionReference();
	var idBrsh = charIDToTypeID( "Brsh" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref132.putEnumerated( idBrsh, idOrdn, idTrgt );
	desc182.putReference( idnull, ref132 );
	var idT = charIDToTypeID( "T   " );
	var desc183 = new ActionDescriptor();
	var idmasterDiameter = stringIDToTypeID( "masterDiameter" );
	var idPxl = charIDToTypeID( "#Pxl" );
	    desc183.putUnitDouble( idmasterDiameter, idPxl, 100.000000 );
	var idBrsh = charIDToTypeID( "Brsh" );
	    desc182.putObject( idT, idBrsh, desc183 );
	executeAction( idsetd, desc182, DialogModes.NO );
	
	// =======================================================
	var idStop = charIDToTypeID( "Stop" );
	var desc239 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc239.putString( idMsge, "This brush clones with more detail. Use the brush at this smaller size, and begin to paint over the main focal areas using small, short strokes." );
	var idCntn = charIDToTypeID( "Cntn" );
	desc239.putBoolean( idCntn, true );

	if (colourAssistant.showTutorialMessages)
		executeAction( idStop, desc239, DialogModes.ALL );

}



///////////////////////////////////////////////////////////////////////////////
// Function: addStrongDetail
// Usage: One of the steps from Listener recorded by the Dr.
//        some logic added to manage the preset files used
// Input: <nothing>
// Return: <nothing> but the document sure did change!!!!
///////////////////////////////////////////////////////////////////////////////
colourAssistant.addStrongDetail = function() {
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc188 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref135 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref135.putName( idLyr, "Vibrance_3" );
	desc188.putReference( idnull, ref135 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc188.putBoolean( idMkVs, false );
	executeAction( idslct, desc188, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc189 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref136 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	    ref136.putClass( idLyr );
	desc189.putReference( idnull, ref136 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc190 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idMltp = charIDToTypeID( "Mltp" );
	    desc190.putEnumerated( idMd, idBlnM, idMltp );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc189.putObject( idUsng, idLyr, desc190 );
	executeAction( idMk, desc189, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
	desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Layer_4" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );

	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc191 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref137 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	    ref137.putClass( idAdjL );
	desc191.putReference( idnull, ref137 );
	var idUsng = charIDToTypeID( "Usng" );
	var desc192 = new ActionDescriptor();
	var idGrup = charIDToTypeID( "Grup" );
	desc192.putBoolean( idGrup, true );
	var idType = charIDToTypeID( "Type" );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc192.putClass( idType, idvibrance );
	var idAdjL = charIDToTypeID( "AdjL" );
	    desc191.putObject( idUsng, idAdjL, desc192 );
	executeAction( idMk, desc191, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc11 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref9 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref9.putEnumerated( idLyr, idOrdn, idTrgt );
	desc11.putReference( idnull, ref9 );
	var idT = charIDToTypeID( "T   " );
	var desc12 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc12.putString( idNm, "Vibrance_4" );
	var idLyr = charIDToTypeID( "Lyr " );
		desc11.putObject( idT, idLyr, desc12 );
	executeAction( idsetd, desc11, DialogModes.NO );

	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc193 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref138 = new ActionReference();
	var idAdjL = charIDToTypeID( "AdjL" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref138.putEnumerated( idAdjL, idOrdn, idTrgt );
	desc193.putReference( idnull, ref138 );
	var idT = charIDToTypeID( "T   " );
	var desc194 = new ActionDescriptor();
	var idvibrance = stringIDToTypeID( "vibrance" );
	desc194.putInteger( idvibrance, 79 );
	var idStrt = charIDToTypeID( "Strt" );
	    desc194.putInteger( idStrt, 74 );
	var idvibrance = stringIDToTypeID( "vibrance" );
	    desc193.putObject( idT, idvibrance, desc194 );
	executeAction( idsetd, desc193, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc195 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref139 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref139.putName( idLyr, "Layer_4" );
	desc195.putReference( idnull, ref139 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc195.putBoolean( idMkVs, false );
	executeAction( idslct, desc195, DialogModes.NO );
	
	// =======================================================
	var classTool = stringIDToTypeID('toolPreset');
	if ( ! colourAssistant.findPresetByName('tim strong detail', classTool) ) {
		colourAssistant.loadPreset(app.path + '/Presets/Tools/Watercolour Presets.tpl', classTool);
	}
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc196 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref140 = new ActionReference();
	var idtoolPreset = stringIDToTypeID( "toolPreset" );
	ref140.putName( idtoolPreset, "tim strong detail" );
	    desc196.putReference( idnull, ref140 );
	executeAction( idslct, desc196, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc197 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref141 = new ActionReference();
	var idBrsh = charIDToTypeID( "Brsh" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref141.putEnumerated( idBrsh, idOrdn, idTrgt );
	desc197.putReference( idnull, ref141 );
	var idT = charIDToTypeID( "T   " );
	var desc198 = new ActionDescriptor();
	var idmasterDiameter = stringIDToTypeID( "masterDiameter" );
	var idPxl = charIDToTypeID( "#Pxl" );
	    desc198.putUnitDouble( idmasterDiameter, idPxl, 100.000000 );
	var idBrsh = charIDToTypeID( "Brsh" );
	    desc197.putObject( idT, idBrsh, desc198 );
	executeAction( idsetd, desc197, DialogModes.NO );
	
	// =======================================================
	var idStop = charIDToTypeID( "Stop" );
	var desc239 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc239.putString( idMsge, "With this brush you will be cloning with maximum detail, tone and colour. Use this brush very sparingly, with short strokes, over the main focal points." );
	var idCntn = charIDToTypeID( "Cntn" );
	desc239.putBoolean( idCntn, true );

	if (colourAssistant.showTutorialMessages)
		executeAction( idStop, desc239, DialogModes.ALL );

}



///////////////////////////////////////////////////////////////////////////////
// Function: addHighlightDetail
// Usage: One of the steps from Listener recorded by the Dr.
//        some logic added to manage the preset files used
// Input: <nothing>
// Return: <nothing> but the document sure did change!!!!
///////////////////////////////////////////////////////////////////////////////
colourAssistant.addHighlightDetail = function() {
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc216 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref159 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	ref159.putName( idLyr, "Vibrance_4" );
	desc216.putReference( idnull, ref159 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc216.putBoolean( idMkVs, false );
	executeAction( idslct, desc216, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc217 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref160 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref160.putEnumerated( idLyr, idOrdn, idBckw );
	desc217.putReference( idnull, ref160 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelection = stringIDToTypeID( "addToSelection" );
	desc217.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelection );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc217.putBoolean( idMkVs, false );
	executeAction( idslct, desc217, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc218 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref161 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref161.putEnumerated( idLyr, idOrdn, idBckw );
	desc218.putReference( idnull, ref161 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelection = stringIDToTypeID( "addToSelection" );
	desc218.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelection );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc218.putBoolean( idMkVs, false );
	executeAction( idslct, desc218, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc219 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref162 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref162.putEnumerated( idLyr, idOrdn, idBckw );
	desc219.putReference( idnull, ref162 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelection = stringIDToTypeID( "addToSelection" );
	desc219.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelection );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc219.putBoolean( idMkVs, false );
	executeAction( idslct, desc219, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc220 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref163 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref163.putEnumerated( idLyr, idOrdn, idBckw );
	desc220.putReference( idnull, ref163 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelection = stringIDToTypeID( "addToSelection" );
	desc220.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelection );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc220.putBoolean( idMkVs, false );
	executeAction( idslct, desc220, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc221 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref164 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref164.putEnumerated( idLyr, idOrdn, idBckw );
	desc221.putReference( idnull, ref164 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelection = stringIDToTypeID( "addToSelection" );
	desc221.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelection );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc221.putBoolean( idMkVs, false );
	executeAction( idslct, desc221, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc222 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref165 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref165.putEnumerated( idLyr, idOrdn, idBckw );
	desc222.putReference( idnull, ref165 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelection = stringIDToTypeID( "addToSelection" );
	desc222.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelection );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc222.putBoolean( idMkVs, false );
	executeAction( idslct, desc222, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc223 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref166 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idBckw = charIDToTypeID( "Bckw" );
	    ref166.putEnumerated( idLyr, idOrdn, idBckw );
	desc223.putReference( idnull, ref166 );
	var idselectionModifier = stringIDToTypeID( "selectionModifier" );
	var idselectionModifierType = stringIDToTypeID( "selectionModifierType" );
	var idaddToSelection = stringIDToTypeID( "addToSelection" );
	desc223.putEnumerated( idselectionModifier, idselectionModifierType, idaddToSelection );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc223.putBoolean( idMkVs, false );
	executeAction( idslct, desc223, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc224 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref167 = new ActionReference();
	var idlayerSection = stringIDToTypeID( "layerSection" );
	    ref167.putClass( idlayerSection );
	desc224.putReference( idnull, ref167 );
	var idFrom = charIDToTypeID( "From" );
	var ref168 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	        ref168.putEnumerated( idLyr, idOrdn, idTrgt );
	    desc224.putReference( idFrom, ref168 );
	executeAction( idMk, desc224, DialogModes.NO );
	
	// =======================================================
	var idMrgtwo = charIDToTypeID( "Mrg2" );
	executeAction( idMrgtwo, undefined, DialogModes.NO );
	
	// =======================================================
	var idMk = charIDToTypeID( "Mk  " );
	var desc225 = new ActionDescriptor();
	var idNw = charIDToTypeID( "Nw  " );
	var idChnl = charIDToTypeID( "Chnl" );
	desc225.putClass( idNw, idChnl );
	var idAt = charIDToTypeID( "At  " );
	var ref169 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idChnl = charIDToTypeID( "Chnl" );
	var idMsk = charIDToTypeID( "Msk " );
	    ref169.putEnumerated( idChnl, idChnl, idMsk );
	desc225.putReference( idAt, ref169 );
	var idUsng = charIDToTypeID( "Usng" );
	var idUsrM = charIDToTypeID( "UsrM" );
	var idRvlA = charIDToTypeID( "RvlA" );
	    desc225.putEnumerated( idUsng, idUsrM, idRvlA );
	executeAction( idMk, desc225, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc226 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref170 = new ActionReference();
	var idPbTl = charIDToTypeID( "PbTl" );
	        ref170.putClass( idPbTl );
	    desc226.putReference( idnull, ref170 );
	executeAction( idslct, desc226, DialogModes.NO );
	
	// =======================================================
	var classTool = stringIDToTypeID('toolPreset');
	if ( ! colourAssistant.findPresetByName('highlights', classTool) ) {
		colourAssistant.loadPreset(app.path + '/Presets/Tools/Watercolour Presets.tpl', classTool);
	}
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc227 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref171 = new ActionReference();
	var idtoolPreset = stringIDToTypeID( "toolPreset" );
	ref171.putName( idtoolPreset, "highlights" );
	    desc227.putReference( idnull, ref171 );
	executeAction( idslct, desc227, DialogModes.NO );
	
	// =======================================================
	var idslct = charIDToTypeID( "slct" );
	var desc228 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref172 = new ActionReference();
	var idChnl = charIDToTypeID( "Chnl" );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref172.putEnumerated( idChnl, idOrdn, idTrgt );
	desc228.putReference( idnull, ref172 );
	var idMkVs = charIDToTypeID( "MkVs" );
	    desc228.putBoolean( idMkVs, false );
	executeAction( idslct, desc228, DialogModes.NO );
	
	// =======================================================
	var idStop = charIDToTypeID( "Stop" );
	var desc239 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc239.putString( idMsge, "If needed, this brush will add subtle highlights back into the image.  This brush will erase all colour while leaving the paper texture untouched." );
	var idCntn = charIDToTypeID( "Cntn" );
	desc239.putBoolean( idCntn, true );

	if (colourAssistant.showTutorialMessages)
		executeAction( idStop, desc239, DialogModes.ALL );

}



///////////////////////////////////////////////////////////////////////////////
// Function: finishStep
// Usage: One of the steps from Listener recorded by the Dr.
//        some logic added to manage the preset files used
// Input: <nothing>
// Return: <nothing> but the document sure did change!!!!
///////////////////////////////////////////////////////////////////////////////
colourAssistant.finishStep = function() {
	// =======================================================
	var idFltI = charIDToTypeID( "FltI" );
	executeAction( idFltI, undefined, DialogModes.NO );
	
	// =======================================================
	var idDplc = charIDToTypeID( "Dplc" );
	var desc229 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref173 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref173.putEnumerated( idLyr, idOrdn, idTrgt );
	desc229.putReference( idnull, ref173 );
	var idVrsn = charIDToTypeID( "Vrsn" );
	    desc229.putInteger( idVrsn, 5 );
	executeAction( idDplc, desc229, DialogModes.NO );
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc230 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref174 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	    ref174.putEnumerated( idLyr, idOrdn, idTrgt );
	desc230.putReference( idnull, ref174 );
	var idT = charIDToTypeID( "T   " );
	var desc231 = new ActionDescriptor();
	var idMd = charIDToTypeID( "Md  " );
	var idBlnM = charIDToTypeID( "BlnM" );
	var idOvrl = charIDToTypeID( "Ovrl" );
	    desc231.putEnumerated( idMd, idBlnM, idOvrl );
	var idLyr = charIDToTypeID( "Lyr " );
	    desc230.putObject( idT, idLyr, desc231 );
	executeAction( idsetd, desc230, DialogModes.NO );
	
	// =======================================================
	var idDstt = charIDToTypeID( "Dstt" );
	executeAction( idDstt, undefined, DialogModes.NO );
	
	// =======================================================
	var idHghP = charIDToTypeID( "HghP" );
	var desc232 = new ActionDescriptor();
	var idRds = charIDToTypeID( "Rds " );
	var idPxl = charIDToTypeID( "#Pxl" );
	    desc232.putUnitDouble( idRds, idPxl, 2.000000 );
	executeAction( idHghP, desc232, DialogModes.NO );
	
		// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc233 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref175 = new ActionReference();
	var idLyr = charIDToTypeID( "Lyr " );
	var idOrdn = charIDToTypeID( "Ordn" );
	var idTrgt = charIDToTypeID( "Trgt" );
	ref175.putEnumerated( idLyr, idOrdn, idTrgt );
	desc233.putReference( idnull, ref175 );
	var idT = charIDToTypeID( "T   " );
	var desc234 = new ActionDescriptor();
	var idNm = charIDToTypeID( "Nm  " );
	desc234.putString( idNm, "High Pass Sharpen" );
	var idLyr = charIDToTypeID( "Lyr " );
	desc233.putObject( idT, idLyr, desc234 );
	executeAction( idsetd, desc233, DialogModes.NO );
	
	// =======================================================
	
	colourAssistant.deleteMyPattern();
	
	// =======================================================
	
	var idStop = charIDToTypeID( "Stop" );
	var desc239 = new ActionDescriptor();
	var idMsge = charIDToTypeID( "Msge" );
	desc239.putString( idMsge, "Your watercolour painting is complete!  Be sure and save your painting with a new name so you do not write over the original. " );
	var idCntn = charIDToTypeID( "Cntn" );
	desc239.putBoolean( idCntn, true );

	if (colourAssistant.showTutorialMessages)
		executeAction( idStop, desc239, DialogModes.ALL );

}



///////////////////////////////////////////////////////////////////////////////
// Function: deleteMyPattern
// Usage: You can only delete a pattern by index? What?
// Input: <nothing>, uses global on object
// Return: <nothing> deleted pattern
///////////////////////////////////////////////////////////////////////////////
colourAssistant.deleteMyPattern = function() {
	if (colourAssistant.deleteThisPattern != -1) {
		// =======================================================
		var idDlt = charIDToTypeID( "Dlt " );
		var desc5 = new ActionDescriptor();
		var idnull = charIDToTypeID( "null" );
		var ref4 = new ActionReference();
		var idPtrn = charIDToTypeID( "Ptrn" );
		ref4.putIndex( idPtrn, colourAssistant.deleteThisPattern );
		desc5.putReference( idnull, ref4 );
		executeAction( idDlt, desc5, DialogModes.NO );
	}
}



///////////////////////////////////////////////////////////////////////////////
// Function: resetThings
// Usage: Time to start over, delete the patter I made and revert the document
// Input: <nothing>
// Return: <nothing> but the document sure did change!!!!
///////////////////////////////////////////////////////////////////////////////
colourAssistant.resetThings = function() {
	colourAssistant.deleteMyPattern();
	if (documents.length > 0 && confirm("Do you want to revert the document?")) {
		executeAction(charIDToTypeID("Rvrt"), undefined, DialogModes.NO);
	}
}



///////////////////////////////////////////////////////////////////////////////
// Function: findPresetByName
// Usage: tell me if a preset is already loaded
// Input: preset name and class of preset
// Return: true for found it, false otherwise
///////////////////////////////////////////////////////////////////////////////
colourAssistant.findPresetByName = function( presetName, presetClass ) {
	var ref = new ActionReference();
	var presetManagerStrID = stringIDToTypeID( 'presetManager');
	ref.putProperty( charIDToTypeID( 'Prpr' ), presetManagerStrID );
	ref.putEnumerated( charIDToTypeID( 'capp' ), charIDToTypeID( 'Ordn' ), charIDToTypeID( 'Trgt' ) ); 
	var desc = executeActionGet( ref );
	if ( desc.count > 0 && desc.hasKey( presetManagerStrID ) ) {
		var list = desc.getList( presetManagerStrID );
		for ( var i = 0; i < list.count; i++ ) {
			var listType = list.getObjectType( i );
			if ( listType == presetClass ) {
				var toolDescObj = list.getObjectValue( i );
				var keyName = charIDToTypeID( 'Nm  ' );
				if ( toolDescObj.count > 0 && toolDescObj.hasKey( keyName ) ) {
					var toolNameList = toolDescObj.getList( keyName );
					for ( var ii = 0; ii < toolNameList.count; ii++ ) {
						var toolName = toolNameList.getString( ii );
						if ( toolName == presetName ) {
							return true;
						}
					}
				}
			}
		}
	}
	return false;
}



///////////////////////////////////////////////////////////////////////////////
// Function: loadPreset
// Usage: load a preset given a full path and a preset class
// Input: full path to file as string, preset class
// Return: preset file loaded <nothing>
///////////////////////////////////////////////////////////////////////////////
colourAssistant.loadPreset = function( inPresetFileName, inPresetClass ) {
	
	// =======================================================
	var idsetd = charIDToTypeID( "setd" );
	var desc2 = new ActionDescriptor();
	var idnull = charIDToTypeID( "null" );
	var ref2 = new ActionReference();
	   var idPrpr = charIDToTypeID( "Prpr" );
	   ref2.putProperty( idPrpr, inPresetClass );
	   var idcapp = charIDToTypeID( "capp" );
	   var idOrdn = charIDToTypeID( "Ordn" );
	   var idTrgt = charIDToTypeID( "Trgt" );
	   ref2.putEnumerated( idcapp, idOrdn, idTrgt );
		desc2.putReference( idnull, ref2 );
		var idT = charIDToTypeID( "T   " );
		desc2.putPath( idT, new File( inPresetFileName ) );
	var idAppe = charIDToTypeID( "Appe" );
	desc2.putBoolean( idAppe, true );
	executeAction( idsetd, desc2, DialogModes.NO );

}



///////////////////////////////////////////////////////////////////////////////
// Function: howManyPresets
// Usage: Get the index of the preset I just made
// Input: kind of preset i'm looking for, classBrush, toolPreset, classPattern
// Return: number of presets
///////////////////////////////////////////////////////////////////////////////
colourAssistant.howManyPresets = function( inPresetClass ) {
    var count = 0;
	var ref = new ActionReference();
	var presetManagerStrID = stringIDToTypeID( 'presetManager');
	ref.putProperty( charIDToTypeID( 'Prpr' ), presetManagerStrID );
	ref.putEnumerated( charIDToTypeID( 'capp' ), charIDToTypeID( 'Ordn' ), charIDToTypeID( 'Trgt' ) ); 
	var desc = executeActionGet( ref );
	if ( desc.count > 0 && desc.hasKey( presetManagerStrID ) ) {
		var list = desc.getList( presetManagerStrID );
		for ( var i = 0; i < list.count; i++ ) {
			var listType = list.getObjectType( i );
			if ( listType == inPresetClass ) {
				var toolDescObj = list.getObjectValue( i );
				var keyName = charIDToTypeID( 'Nm  ' );
				if ( toolDescObj.count > 0 && toolDescObj.hasKey( keyName ) ) {
					var toolNameList = toolDescObj.getList( keyName );
					count = toolNameList.count;
                 }
             }
         }
     }
    return count;
}


///////////////////////////////////////////////////////////////////////////////
// Function: storePreferences
///////////////////////////////////////////////////////////////////////////////
colourAssistant.storePreferences = function( inParamsAsSource ) {
	try {
		var params = colourAssistant.paramsToParams( inParamsAsSource )
		var desc = new ActionDescriptor();
		desc.putString(  stringIDToTypeID( "version" ), params.version );
		desc.putString(  stringIDToTypeID( "stepNumber" ), params.stepNumber );
		desc.putBoolean( stringIDToTypeID( "showHelpMessage" ), params.showHelpMessage );
		desc.putBoolean( stringIDToTypeID( "showStepMessage" ), params.showStepMessage );
		app.putCustomOptions( "b572e62f-bf72-4a1a-850c-f87b939b6b2d", desc );
	} 
	catch(e) { 
		;  
	}
	
}


///////////////////////////////////////////////////////////////////////////////
// Function: retrievePreferences
///////////////////////////////////////////////////////////////////////////////
colourAssistant.retrievePreferences = function() {
	var s; 
	try {
		var desc = app.getCustomOptions( "b572e62f-bf72-4a1a-850c-f87b939b6b2d" );
		if ( desc.count > 0 ) {
			s = '<object>';
			s += colourAssistant.propertyToXML( desc.getString(  stringIDToTypeID( "version" ) ).toString(), "version" );
			s += colourAssistant.propertyToXML( desc.getString(  stringIDToTypeID( "stepNumber" ) ).toString(), "stepNumber" );
			s += colourAssistant.propertyToXML( desc.getBoolean( stringIDToTypeID( "showHelpMessage" ) ).toString(), "showHelpMessage" );
			s += colourAssistant.propertyToXML( desc.getBoolean( stringIDToTypeID( "showStepMessage" ) ).toString(), "showStepMessage" );
			s += '</object>';
		} else {
			; // s = colourAssistant.errorToXML(new Error( "noprefs" ) );
		}
	}
	catch(e) {
		; // s = colourAssistant.errorToXML( e );
	}
	return s;
}



} // end overall try catch block
catch(e) {
	if (colourAssistant.showAlerts) {
		alert(localize("$$$/ColourAssistant/alert/alert_key_value={0} : {1}").replace("{0}", e).replace("{1}", e.line));
	}
}

// end ColourAssistant.jsx
