/**************************************************************************
	ADOBE SYSTEMS INCORPORATED
	 Copyright 2010 Adobe Systems Incorporated
	 All Rights Reserved.

	NOTICE:  Adobe permits you to use, modify, and distribute this file
	in accordance with the terms of the Adobe license agreement accompanying
	it.  If you have received this file from a source other than Adobe, then
	your use, modification, or distribution of it requires the prior written
	permission of Adobe.
**************************************************************************/

import com.adobe.csxs.core.CSXSInterface;
import com.adobe.csxs.events.*;
import com.adobe.csxs.types.*;

import mx.collections.*;
import mx.core.*;
import mx.styles.StyleManager;

// some unicode test strings to play with, 
// if you see dots after JPEG that means your 
// font does not support J but the chars are still there
// "\u4eca\u65e5\u306f\u4e16\u754c"; // "JPEG世界需要溝";

// Embed the images so we can use them in the VBox "icon" style properties.
[Embed(source="one.png")]
[Bindable] public var iconOne:Class;

[Embed(source="two.png")]
[Bindable] public var iconTwo:Class;

[Embed(source="three.png")]
[Bindable] public var iconThree:Class;

[Embed(source="four.png")]
[Bindable] public var iconFour:Class;

[Embed(source="five.png")]
[Bindable] public var iconFive:Class;

/* These two new variables are used to make it possible to adjust the panel
	width (accordionWidth) and to adjust the fontsize (fontSize). If necessary
	you can create additional variables to fix UI bugs if the length of string
	translations cause unique problems,	but it always best to minimize this. 
	Don't go crazy adding variables to make the UI adjustable, try to make 
	full use of the Flex auto-layout capabilities and spacers.
	Match the english zstring for all of these 
*/
[Bindable] private var accordionWidth:Number = 260;
[Bindable] private var panelWidth:Number = 270;
[Bindable] private var panelHeight:Number = 325;
[Bindable] private var fontSize:Number = 10;

[Bindable]
public var fontXML:XML;

[Bindable]
public var fontStyleXML:XMLList;

public var colorPickerHex:String;
public var strAlertText:String;
public var strLoadText:String;
public var strSaveText:String;
public var strResetText:String;
public var strHelpText:String;
public var strEntourage:String;
public var strMacMail:String;
public var strMSOutlook:String;
public var strMSOutlookExp:String;
public var strThunderbird:String;
public var csxs:CSXSInterface;
public var showErrors:Boolean = true;
public var strVersionText:String = "Version 2.2.2";
public var blackTextColor:Number = 0; // i get this from the label, it is the default
public var whiteTextColor:Number = 13555671; // Red 206, green 215, blue 215
public var greenTextColor:Number = 26214; // the doctor recommends two of these every morning
public var defaultDisabledColor:Number = 0;
public var defaultFillColors:Object = null;
public var showHelpMessage:Boolean = true;


/**
 * Function:		getGeometry
 * Description:		Force the size of the window all the time because I don't resize well
 */
private function getGeometry():WindowGeometry {
	var panel_X:Number = 100;
	var panel_Y:Number = 100;
	var panel_W:Number = panelWidth;
	var panel_H:Number = panelHeight;
	var windowsize:WindowGeometry = new WindowGeometry(panel_X,panel_Y,panel_W,panel_H);
	return windowsize;
}


/**
	Function:		init
	Description:	Initializes the size of the panel to a set size. The
					function also retrieves the Adobe Photoshop's host environment
					properties including the background color, font family, and font size
					to copy for the panel itself.
*/
private function init():void {	
  try {
  	
  	csxs = CSXSInterface.getInstance();						  	

	getFonts();
	
	localizePanel();

	getCurrentSettings();
	
	updateUIFromCurrentSettings();
	
	updatePanelMenu();
	
	blackTextColor = rbUseLogoFile.getStyle("color");
	
	defaultDisabledColor = ddFontFamily.getStyle("disabledColor");
	
	defaultFillColors = ddFontFamily.getStyle("fillColors");

	var result:SyncRequestResult = csxs.getHostEnvironment();
   	if (SyncRequestResult.COMPLETE == result.status) {
		var hostData:HostEnvironment = result.data;
		var skinInfo:AppSkinInfo = hostData.appSkinInfo;
		StyleManager.getStyleDeclaration("global").setStyle("fontFamily", skinInfo.baseFontFamily);
		StyleManager.getStyleDeclaration("global").setStyle("fontSize", skinInfo.baseFontSize);
		setColors(skinInfo.panelBackgroundColor.color.rgb);
		}

	csxs.requestStateChange(StateChangeEvent.WINDOW_RESIZE, getGeometry());
	
	csxs.addEventListener(AppReskinEvent.APPLICATION_RESKIN, appReskinEvent);

	// Tell Photoshop to keep me in memory even if the user closes the panel	
	csxs.evalScript("PhotoshopPersistent");
	
	maybeShowHelp();
	
  }
  
  catch (errObject:Error) {
  		myError(errObject);
  }
	
}


/**
 * Function:		localizePanel
 * Description:		Ask Photoshop to translate all my strings
 * 				  	Strings with numbers are to allow localized versions
 * 					to adjust my widget positions
 */
private function localizePanel():void {
	strLoadText = localize('$$$/watermark/Load=Load Settings');
	strSaveText = localize('$$$/watermark/Save=Save Settings');
	strResetText = localize('$$$/watermark/Reset=Reset Preferences');
	strHelpText = localize('$$$/Actions/Enum/Help/Help=Help');
	accordionWidth = Number(localize('$$$/watermark/accordionWidth=260'));
	panelWidth = Number(localize('$$$/watermark/panelWidth=270'));
	panelHeight = Number(localize('$$$/watermark/panelHeight=325'));
	fontSize = Number(localize('$$$/watermark/fontSize=10'));
	vbSelectSource.label=  localize('$$$/watermark/label/selectsource=Select Watermark Source File');
	btnSelectWatermark.label = localize('$$$/watermark/button/selectfile=Select File');
	rbUseLogoFile.label = localize('$$$/watermark/radiobutton/useLogoFile=Use Logo File');
    stSelectedWatermark.text = localize('$$$/watermark/label/nofile=No File Selected');
    stSelectedWatermark.toolTip = stSelectedWatermark.text;
	rbUseTextEntry.label = localize('$$$/watermark/radiobutton/useTextEntry=Use Text Entry');
	cbAppendFileNames.label = localize('$$$/watermark/checkbox/appendFileName=Append File Name');
	stTextColor.text = localize('$$$/watermark/label/textColor= Text Color  ');	            
    vbSelectImagesToProcess.label = localize('$$$/watermark/label/selectimages=Select Images to Process');
	btnSelectInput.label = localize('$$$/watermark/button/selectfolder=Select Folder');
	stSelectedInput.text = localize('$$$/watermark/label/nofolder=No Folder Selected');
	cbUseOpenImages.label = localize('$$$/watermark/checkbox/useopenimg=Use Open Images');
    lblSelectSaveLocation.text = localize('$$$/watermark/label/selectlocation=Select Location to Save Images');
	btnSelectOutput.label = localize('$$$/watermark/button/selectfolder=Select Folder');
	cbMailIt.label = localize('$$$/watermark/checkbox/mailit=Mail To: ');
	stSelectedOutput.text = localize('$$$/watermark/label/nofolder=No Folder Selected');
	vbPositionStyle.label = localize('$$$/watermark/label/selectpossty=Select Watermark Position and Style');
	lblHorzOffset.text = localize('$$$/watermark/label/horzOffset=Horizonal Offset:');
	lblVertOffset.text = localize('$$$/watermark/label/vertOffset=Vertical Offset:');
	stSizeToFitWpx.text = stSizeToFitHpx.text = lblPx1.text = lblPx2.text = localize('$$$/JavaScripts/ImageProcessor/PX=px')
	lblPerc3.text = stWaterMarkSizePercent.text = unescape("%" + localize('$$$/watermark/label/percentsignescaped=25'));
	stWaterMarkSize.text = localize('$$$/watermark/label/scale=Scale:');
	lblOpacity.text = localize('$$$/watermark/label/opacity=Opacity:');
	vbExportJPEG.label = localize('$$$/watermark/label/selectjpegset=Select JPEG Export Settings');
	rbSaveJPEG.label = localize('$$$/watermark/button/savejpeg=Save as Standard JPEG Image');
	rbSaveForWeb.label = localize('$$$/watermark/button/saveweb=Save as JPEG for the Web');
	cbSmartSharpen.label = localize('$$$/watermark/checkbox/smartsharpen=Smart Sharpen');
	cbShowSmartSharpen.label = localize('$$$/watermark/checkbox/smartsharpenoptions=Sharpen Options');
	cbSizeToFit.label = localize('$$$/watermark/checkbox/fit=Size to fit');
	stQuality.text = localize('$$$/watermark/label/quiality=Quality:')
	stResolution.text = localize('$$$/watermark/label/resolution=Resolution:')
	stPixPerInch.text = localize('$$$/watermark/label/pxin=px/in');
	etSizeToFitW.text = etSizeToFitH.text = localize('$$$/watermark/textinput/900px=900');
	stSizeToFitW.text = localize('$$$/watermark/label/fitw=W:');
	stSizeToFitH.text = localize('$$$/watermark/label/fith=H:');
	vbProcessImages.label = localize('$$$/watermark/label/processimg=Process Images');
	btnPreview.label = localize('$$$/watermark/button/preview=Preview');
	btnRun.label = localize('$$$/watermark/button/run=Run');
	strAlertText = localize("$$$/watermark/alertTitle=Watermark Alert");
	var sizeArray:Array = new Array();
	sizeArray.push(localize('$$$/watermark/combobox/ce=Center'));
	sizeArray.push(localize('$$$/watermark/combobox/ct=Center Top'));
	sizeArray.push(localize('$$$/watermark/combobox/cb=Center Bottom'));
	sizeArray.push(localize('$$$/watermark/combobox/cl=Center Left'));
	sizeArray.push(localize('$$$/watermark/combobox/cr=Center Right'));
	sizeArray.push(localize('$$$/watermark/combobox/ll=Lower Left'));
	sizeArray.push(localize('$$$/watermark/combobox/lr=Lower Right'));
	sizeArray.push(localize('$$$/watermark/combobox/ul=Upper Left'));
	sizeArray.push(localize('$$$/watermark/combobox/ur=Upper Right'));
	ddPosition.dataProvider = new ArrayCollection(sizeArray);
	strEntourage = localize('$$$/watermark/combobox/entourage=Microsoft Entourage');
	strMacMail = localize('$$$/watermark/combobox/macmail=Mac Mail');
	strMSOutlook = localize('$$$/watermark/combobox/msoutlook=Microsoft Outlook');
	strMSOutlookExp = localize('$$$/watermark/combobox/msoutlookexpress=Microsoft Outlook Express');
	strThunderbird = localize('$$$/watermark/combobox/thunderbird=Thunderbird');
	var mailArray:Array = new Array();
	var isMac:Boolean = (flash.system.Capabilities.os.search("Mac") != -1);
	if (isMac) {
		mailArray.push(strEntourage);
		mailArray.push(strMacMail);
	} else {
		mailArray.push(strMSOutlook);
		mailArray.push(strMSOutlookExp);
	}
	mailArray.push(strThunderbird);
	ddMailProgram.dataProvider = new ArrayCollection(mailArray);
}


/**
 * Function:		getFonts
 * Description:		Pulls the fonts from Photoshop, either from cached 
 * 					preferences, or from Photoshop itself, depending on 
 * 					whether we have all the fonts, or if this is the first
 * 					time running the app.
 */
private function getFonts():void
{	
	// First see if we have a cached xml list of fonts
	var str:String;
	var result:SyncRequestResult = csxs.retrievePreference("cachedFontList");
	if (SyncRequestResult.COMPLETE == result.status && result.data) {
		
		// We do have a cached list, now we need to see if it has all the latest fonts
		str = unescape(result.data.toString());
		fontXML = new XML(str);
		
		// Get the current number of fonts from Photoshop
		var numFonts:int = -1;
		result = csxs.evalScript("watermark.getNumFonts");
		if (SyncRequestResult.COMPLETE == result.status && result.data) {
			numFonts = parseInt(result.data.numFonts.toString());
		} else throw( Error(localize("$$$/watermark/getfontserr=Cannot evaluate fonts")) );
		
		if( fontXML.@numFonts == numFonts ) {
			// We have the correct number of fonts, so everything is ok. 
			// Set the data providers of the objects and return.
			
			ddFontFamily.dataProvider = fontXML.children().attribute("family");				
			fontStyleXML = fontXML.*.(@family == ddFontFamily.selectedLabel).children();
			ddFontStyle.dataProvider = fontStyleXML;
			
			return;
		}
	} 
				
	// The original stuff is garbage now if it existed
	fontXML = null;
		
	// Either the number of fonts is different, or we don't have a cached version.
	// Request the fonts from photoshop.  This is pretty slow.
	result = csxs.evalScript("watermark.getFonts");
	if (SyncRequestResult.COMPLETE == result.status) {
		
		// Since we've loaded this in for the first time, cache it.
		csxs.storePreference("cachedFontList", result.data.xmlString as String);
		
		str = unescape(result.data.xmlString as String);
		fontXML = new XML(str);				
		
		ddFontFamily.dataProvider = fontXML.children().attribute("family");				
		fontStyleXML = fontXML.*.(@family == ddFontFamily.selectedLabel).children();
		ddFontStyle.dataProvider = fontStyleXML;
		
	} else throw( Error(localize("$$$/watermark/getfontserr=Cannot evaluate fonts")) );
}


/**
 * Functino: 		onFontChange
 * Description: 	When the user changes fonts, update the styles ComboBox
 */
private function onFontChange():void {
	fontStyleXML = fontXML.*.(@family == ddFontFamily.selectedLabel).children();
	ddFontStyle.dataProvider = fontStyleXML;
}


/**
 * Function:		appReskinEvent
 * Description:		Photoshop can now do four colors, change our background and other stuff accordingly
 */
private function appReskinEvent(e:Event):void {
	var result:SyncRequestResult = csxs.getHostEnvironment();
   	if (SyncRequestResult.COMPLETE == result.status) {
		var hostData:HostEnvironment = result.data;
		var skinInfo:AppSkinInfo = hostData.appSkinInfo;
		setColors(skinInfo.panelBackgroundColor.color.rgb);
	}
}


/**
 * Functino: 		setColors
 * Description: 	Set the color for each ui element
 */
private function setColors(c:Number):void {
	this.setStyle("backgroundGradientColors", [c, c]);
	if ( ( ( c >> 16 ) & 0xFF ) > 0x7F ) {
		setEachColor(blackTextColor, whiteTextColor, "myAccordionHeaderWonB", "White");
	} else {
		setEachColor(whiteTextColor, blackTextColor, "myAccordionHeaderBonW", "Black");
	}
}


/**
 * Function:		setEachColor
 * Description:		Set the color on all of our dialog thingies
 */
private function setEachColor(c1:Number, c2:Number, c3:String, c4:String):void {
	accordionMain.setStyle("textRollOverColor", c1);
	accordionMain.setStyle("textSelectedColor", c1);
	accordionMain.setStyle("borderColor", 6842472);
	accordionMain.setStyle("backgroundColor", c2);
	accordionMain.setStyle("headerStyleName", c3);
	rbUseLogoFile.setStyle("color", c1);
	rbUseLogoFile.setStyle("textRollOverColor", c1);
	btnSelectWatermark.setStyle("color", c1);
	btnSelectWatermark.setStyle("textRollOverColor", c1);
	btnSelectWatermark.setStyle("fillColors", [c2, c2, c2, c2]);
	stSelectedWatermark.setStyle("color", c1);
	stSelectedWatermark.setStyle("textRollOverColor", c1);	
	rbUseTextEntry.setStyle("color", c1);
	rbUseTextEntry.setStyle("textRollOverColor", c1);	
	ddFontFamily.setStyle("color", c1);
	ddFontFamily.setStyle("textRollOverColor", "Black");
	ddFontFamily.setStyle("textSelectedColor", "Black");
	// background is black, do something special
	if (c2 == blackTextColor) {
		ddFontFamily.setStyle("disabledColor", "Gray");
		if (ddFontFamily.enabled) {
			ddFontFamily.setStyle("fillColors", [greenTextColor, greenTextColor, greenTextColor, greenTextColor]);
		} else {
			ddFontFamily.setStyle("fillColors", [c2, c2, c2, c2]);
		}
	} else {
		ddFontFamily.setStyle("disabledColor", defaultDisabledColor);
		ddFontFamily.setStyle("fillColors", defaultFillColors);
	}
	ddFontStyle.setStyle("color", c1);
	ddFontStyle.setStyle("textRollOverColor", "Black");
	ddFontStyle.setStyle("textSelectedColor", "Black");
	// background is black, do something special
	if (c2 == blackTextColor) {
		ddFontStyle.setStyle("disabledColor", "Gray");
		if (ddFontStyle.enabled) {
			ddFontStyle.setStyle("fillColors", [greenTextColor, greenTextColor, greenTextColor, greenTextColor]);
		} else {
			ddFontStyle.setStyle("fillColors", [c2, c2, c2, c2]);
		}
	} else {
		ddFontStyle.setStyle("disabledColor", defaultDisabledColor);
		ddFontStyle.setStyle("fillColors", defaultFillColors);
	}
	stTextSize.setStyle("color", c1);
	stTextSize.setStyle("textRollOverColor", c1);	
	cpTextColorPicker.setStyle("color", c1);
	cpTextColorPicker.setStyle("textRollOverColor", c1);	
	stTextColor.setStyle("color", c1);
	stTextColor.setStyle("textRollOverColor", c1);	
	cbAppendFileNames.setStyle("color", c1);
	cbAppendFileNames.setStyle("textRollOverColor", c1);	
	btnSelectInput.setStyle("color", c1);
	btnSelectInput.setStyle("textRollOverColor", c1);
	btnSelectInput.setStyle("fillColors", [c2, c2, c2, c2]);
	stSelectedInput.setStyle("color", c1);
	stSelectedInput.setStyle("textRollOverColor", c1);	
	cbUseOpenImages.setStyle("color", c1);
	cbUseOpenImages.setStyle("textRollOverColor", c1);	
	lblSelectSaveLocation.setStyle("color", c1);
	lblSelectSaveLocation.setStyle("textRollOverColor", c1);	
	btnSelectOutput.setStyle("color", c1);
	btnSelectOutput.setStyle("textRollOverColor", c1);
	btnSelectOutput.setStyle("fillColors", [c2, c2, c2, c2]);
	stSelectedOutput.setStyle("color", c1);
	stSelectedOutput.setStyle("textRollOverColor", c1);	
	cbMailIt.setStyle("color", c1);
	cbMailIt.setStyle("textRollOverColor", c1);	
	ddMailProgram.setStyle("color", c1);
	ddMailProgram.setStyle("textRollOverColor", "Black");
	ddMailProgram.setStyle("textSelectedColor", "Black");
	// background is black, do something special
	if (c2 == blackTextColor) {
		ddMailProgram.setStyle("disabledColor", "Gray");
		if (ddMailProgram.enabled) {
			ddMailProgram.setStyle("fillColors", [greenTextColor, greenTextColor, greenTextColor, greenTextColor]);
		} else {
			ddMailProgram.setStyle("fillColors", [c2, c2, c2, c2]);
		}
	} else {
		ddMailProgram.setStyle("disabledColor", defaultDisabledColor);
		ddMailProgram.setStyle("fillColors", defaultFillColors);
	}
	ddPosition.setStyle("color", c1);
	ddPosition.setStyle("textRollOverColor", "Black");
	ddPosition.setStyle("textSelectedColor", "Black");
	// background is black, do something special
	if (c2 == blackTextColor) {
		ddPosition.setStyle("disabledColor", "Gray");
		if (ddPosition.enabled) {
			ddPosition.setStyle("fillColors", [greenTextColor, greenTextColor, greenTextColor, greenTextColor]);
		} else {
			ddPosition.setStyle("fillColors", [c2, c2, c2, c2]);
		}
	} else {
		ddPosition.setStyle("disabledColor", defaultDisabledColor);
		ddPosition.setStyle("fillColors", defaultFillColors);
	}
	lblHorzOffset.setStyle("color", c1);
	lblHorzOffset.setStyle("textRollOverColor", c1);	
	lblPx1.setStyle("color", c1);
	lblPx1.setStyle("textRollOverColor", c1);	
	lblVertOffset.setStyle("color", c1);
	lblVertOffset.setStyle("textRollOverColor", c1);	
	lblPx2.setStyle("color", c1);
	lblPx2.setStyle("textRollOverColor", c1);	
	stWaterMarkSize.setStyle("color", c1);
	stWaterMarkSize.setStyle("textRollOverColor", c1);	
	stWaterMarkSizePercent.setStyle("color", c1);
	stWaterMarkSizePercent.setStyle("textRollOverColor", c1);	
	lblOpacity.setStyle("color", c1);
	lblOpacity.setStyle("textRollOverColor", c1);	
	lblPerc3.setStyle("color", c1);
	lblPerc3.setStyle("textRollOverColor", c1);	
	rbSaveJPEG.setStyle("color", c1);
	rbSaveJPEG.setStyle("textRollOverColor", c1);	
	rbSaveForWeb.setStyle("color", c1);
	rbSaveForWeb.setStyle("textRollOverColor", c1);	
	cbSmartSharpen.setStyle("color", c1);
	cbSmartSharpen.setStyle("textRollOverColor", c1);	
	cbShowSmartSharpen.setStyle("color", c1);
	cbShowSmartSharpen.setStyle("textRollOverColor", c1);	
	cbSizeToFit.setStyle("color", c1);
	cbSizeToFit.setStyle("textRollOverColor", c1);	
	stQuality.setStyle("color", c1);
	stQuality.setStyle("textRollOverColor", c1);	
	stResolution.setStyle("color", c1);
	stResolution.setStyle("textRollOverColor", c1);	
	stPixPerInch.setStyle("color", c1);
	stPixPerInch.setStyle("textRollOverColor", c1);	
	stSizeToFitW.setStyle("color", c1);
	stSizeToFitW.setStyle("textRollOverColor", c1);	
	stSizeToFitH.setStyle("color", c1);
	stSizeToFitH.setStyle("textRollOverColor", c1);	
	stSizeToFitHpx.setStyle("color", c1);
	stSizeToFitHpx.setStyle("textRollOverColor", c1);	
	stSizeToFitWpx.setStyle("color", c1);
	stSizeToFitWpx.setStyle("textRollOverColor", c1);	
	btnPreview.setStyle("color", c1);
	btnPreview.setStyle("textRollOverColor", c1);
	btnPreview.setStyle("fillColors", [c2, c2, c2, c2]);
	btnRun.setStyle("color", c1);
	btnRun.setStyle("textRollOverColor", c1);
	btnRun.setStyle("fillColors", [c2, c2, c2, c2]);
}


/**
 * Function:	updateUIFromCurrentSettings
 * Description:	Fix up the ui because we just got new settings
 */
private function updateUIFromCurrentSettings():void {
	useOpenImagesClick();
	
	saveJPEGClick( ! rbSaveForWeb.selected );
	
	sizeToFitClick();
	
	updateWatermarkSourceUI(rbUseLogoFile.selected);
	
	cbShowSmartSharpen.enabled = cbSmartSharpen.selected;
	
	mailItClick();
	
}	


/**
 * Function:		useOpenImagesClick
 * Description:		Update the UI to show what options are available or not
 */
private function useOpenImagesClick():void {
	btnSelectInput.enabled = ! cbUseOpenImages.selected;
	stSelectedInput.enabled = ! cbUseOpenImages.selected;
}


/**
 * Function:		mailItClick
 * Description:		Update the UI to show what options are available or not
 */
private function mailItClick():void {
	var c1:Number = ddMailProgram.getStyle("color");
	ddMailProgram.enabled = cbMailIt.selected;
	if (c1 == whiteTextColor) {
		if (ddMailProgram.enabled) {
			ddMailProgram.setStyle("fillColors", [greenTextColor, greenTextColor, greenTextColor, greenTextColor]);
		} else {
			ddMailProgram.setStyle("fillColors", [blackTextColor, blackTextColor, blackTextColor, blackTextColor]);
		}
	}
}


/**
 * Function:		useSmartSharpenClick
 * Description:		Give a warning about how we are going to use smart sharpen. Every time!
 *                  I'll count the days/hours before somebody askes me to do a don't show again checkbox.
 */
private function useSmartSharpenClick():void {
	if ( cbSmartSharpen.selected ) {
		myAlert("$$$/watermark/usesmartsharpen=The Smart Sharpen strength is based on the most recent settings used with this filter. If you have never used the Smart Sharpen filter, then it will use the default settings. Select the Sharpen Options check box to manually adjust the default sharpening strength.");
	}
	cbShowSmartSharpen.enabled = cbSmartSharpen.selected;
}


/**
 * Function:		saveJPEGClick
 * Description:		Update the UI to show what options are available or not
 */
private function saveJPEGClick(regularJPEG:Boolean):void {
	stResolution.enabled = regularJPEG;
	etResolution.enabled = regularJPEG;
	stPixPerInch.enabled = regularJPEG;
}


/**
 * Function:		sizeToFitClick
 * Description:		Update the UI to show what options are available or not
 */
private function sizeToFitClick():void {
	stSizeToFitH.enabled = cbSizeToFit.selected;
	etSizeToFitH.enabled = cbSizeToFit.selected;
	stSizeToFitW.enabled = cbSizeToFit.selected;
	etSizeToFitW.enabled = cbSizeToFit.selected;
	stSizeToFitWpx.enabled = cbSizeToFit.selected;
	stSizeToFitHpx.enabled = cbSizeToFit.selected;
}


/**
 * Function:		onClickImageSourceButton
 * Description:		called when the user enables image watermarks
 */
private function onClickImageSourceButton():void {
	updateWatermarkSourceUI(true);
}


/**
 * Function:		onClickTextSourceButton
 * Description:		called when the user enables text watermarks
 */
private function onClickTextSourceButton():void {	
	updateWatermarkSourceUI(false);
}


/**
 * Function:		updateWatermarkSourceUI
 * Description:		Allows switching between image and text modes in the UI
 */
private function updateWatermarkSourceUI(useImage:Boolean):void {
	var c1:Number = ddFontFamily.getStyle("color");
		
	if( useImage ) {
		etWatermarkText.enabled = ddFontFamily.enabled = ddFontStyle.enabled = 
		stTextSize.enabled = etTextSize.enabled = cpTextColorPicker.enabled =
		cbAppendFileNames.enabled = stTextColor.enabled = false;
		
		if (c1 == whiteTextColor) {
			ddFontFamily.setStyle("fillColors", [blackTextColor, blackTextColor, blackTextColor, blackTextColor]);
			ddFontStyle.setStyle("fillColors", [blackTextColor, blackTextColor, blackTextColor, blackTextColor]);
		}
		
		btnSelectWatermark.enabled = stSelectedWatermark.enabled = 
		stWaterMarkSize.enabled = etWaterMarkSize.enabled =
		stWaterMarkSizePercent.enabled = true;
		
		rbUseLogoFile.selected = true;
	} else {
		btnSelectWatermark.enabled = stWaterMarkSize.enabled = etWaterMarkSize.enabled =
		stWaterMarkSizePercent.enabled = stSelectedWatermark.enabled = false;
		
		stTextSize.enabled = etWatermarkText.enabled = ddFontFamily.enabled = 
		ddFontStyle.enabled = etTextSize.enabled = 
		cpTextColorPicker.enabled = cbAppendFileNames.enabled = 
		stTextColor.enabled = true;
		
		if (c1 == whiteTextColor) {
			ddFontFamily.setStyle("fillColors", [greenTextColor, greenTextColor, greenTextColor, greenTextColor]);
			ddFontStyle.setStyle("fillColors", [greenTextColor, greenTextColor, greenTextColor, greenTextColor]);
		}
		
		rbUseTextEntry.selected = true;
	}
}			


/**
	Function:		runProcess
	Description:	None of the following is true.....
	 *              Save off the settings and pass everything to 
	 * 				the main Photoshop JavaScript.
*/
private function runProcess(onOneImage:Boolean):void {
	try {
		
		if ( ! settingsAreValid() )
			return;

		var params:String = paramsToParams(onOneImage);
		
		saveCurrentSettings(params);

		csxs.evalScript("watermark.runProcess", params);
		
		csxs.requestStateChange(StateChangeEvent.WINDOW_LOSE_FOCUS, null);
	}
  	catch (errObject:Error) {
  		myError(errObject);
  	}
}


/**
 * Function:	resetToDefaults
 * Description:	These are my defaults
 */
private function resetToDefaults():void {
	try {
		rbUseLogoFile.selected = true;
		rbUseTextEntry.selected = ! rbUseLogoFile.selected;
		etWatermarkText.text = "";
		ddFontFamily.selectedIndex = 0;
		ddFontStyle.selectedIndex = 0;
		etTextSize.text = "24"; 
		cpTextColorPicker.selectedColor = 0;
		cbAppendFileNames.selected = false;
	    stSelectedWatermark.text = localize('$$$/watermark/label/nofile=No File Selected');
	    stSelectedWatermark.toolTip = stSelectedWatermark.text;
		stSelectedInput.text = localize('$$$/watermark/label/nofolder=No Folder Selected');
	    stSelectedInput.toolTip = stSelectedWatermark.text;
		stSelectedOutput.text = localize('$$$/watermark/label/nofolder=No Folder Selected');
	    stSelectedOutput.toolTip = stSelectedWatermark.text;
	    cbMailIt.selected = false;
		cbUseOpenImages.selected = false;
		ddPosition.selectedIndex = 0;
		ddMailProgram.selectedIndex = 0;
		etWaterMarkSize.text = "50";
		etWaterMarkOpacity.text = "100";
		etVerticalOffset.text = "20";
		etHorizontalOffset.text = "20";
		etQuality.text = "10";
		etResolution.text = "72";
		cbSizeToFit.selected = true;
		etSizeToFitW.text = etSizeToFitH.text = localize('$$$/watermark/textinput/900px=900');
		rbSaveForWeb.selected = false;
		rbSaveJPEG.selected = ! rbSaveForWeb.selected;
		cbSmartSharpen.selected = true;
		cbShowSmartSharpen.selected = false;
		cbShowSmartSharpen.enabled = false;
		accordionMain.selectedIndex = 0;
	}	
	catch(errObject:Error) {
		myError(errObject);
	}
}


/**
 * Function:	paramsToParams
 * Description:	Gather up our settings as Obect as source
 */
private function paramsToParams(onOneImage:Boolean):String {
	// you can get the dialog into a state where there is no style selected
	// this will try to force a selection
	var localFontStyle:String;
	try {
		localFontStyle = escape(encodeURIComponent(ddFontStyle.selectedLabel));
	}
	catch(errObject:Error) {
		ddFontStyle.selectedIndex = 0;
		localFontStyle = escape(encodeURIComponent(ddFontStyle.selectedLabel));
	}
	var s:String = "({ rbUseLogoFile:" + rbUseLogoFile.selected.toString() + "," + 
		     	"etWatermarkText:'" + escape(encodeURIComponent(etWatermarkText.text)) + "'," + 
		     	"ddFontFamily:'" + escape(encodeURIComponent(ddFontFamily.selectedLabel)) + "'," +
		     	"ddFontStyle:'" + localFontStyle + "'," +
		     	"etTextSize:'" + escape(encodeURIComponent(etTextSize.text)) + "'," + 
		     	"cpTextColorPicker:'" + rgbToHex(cpTextColorPicker.selectedColor) + "'," +
		     	"cbAppendFileNames:" + cbAppendFileNames.selected.toString() + "," +
		     	"stSelectedWatermark:'" + escape(encodeURIComponent(stSelectedWatermark.text)) + "'," +
                "stSelectedInput:'" + escape(encodeURIComponent(stSelectedInput.text)) + "'," +
                "stSelectedOutput:'" + escape(encodeURIComponent(stSelectedOutput.text)) + "'," +
                "cbUseOpenImages:" +  cbUseOpenImages.selected.toString() + "," +
                "cbMailIt:" +  cbMailIt.selected.toString() + "," +
                "ddMailProgram:'" + ddMailProgram.selectedItem.toString() + "'," +
                "ddPosition:'" + ddPosition.selectedItem.toString() + "'," +
                "etWaterMarkSize:" + escape(encodeURIComponent(etWaterMarkSize.text)) + "," +
                "etWaterMarkOpacity:" + escape(encodeURIComponent(etWaterMarkOpacity.text)) + "," +
                "etVerticalOffset:'" + escape(encodeURIComponent(etVerticalOffset.text)) + "'," +
                "etHorizontalOffset:'" + escape(encodeURIComponent(etHorizontalOffset.text)) + "'," +
                "etQuality:" + escape(encodeURIComponent(etQuality.text)) + "," +
                "etResolution:'" + escape(encodeURIComponent(etResolution.text)) + "'," +
                "cbSizeToFit:" + cbSizeToFit.selected.toString() + "," +
                "etSizeToFitW:'" + escape(encodeURIComponent(etSizeToFitW.text)) + "'," +
                "etSizeToFitH:'" + escape(encodeURIComponent(etSizeToFitH.text)) + "'," +
                "rbSaveForWeb:" + rbSaveForWeb.selected.toString() + "," +
                "cbSmartSharpen:" + cbSmartSharpen.selected.toString() + "," +
                "cbShowSmartSharpen:" + cbShowSmartSharpen.selected.toString() + "," +
                "cbOnOneImage:" + onOneImage.toString() + "," +
                "showHelpMessage:" + showHelpMessage.toString() + "," +
                "accordionMain:'" + accordionMain.selectedIndex.toString() + "'" + 
	         "})";
	s = encodeURIComponent(s);
	s = escape(s);
	return s;
}


/**
 * Function:	paramsFromParams
 * Description:	Update our dialog with these parameters
 */
private function paramsFromParams(inParams:Object):void {
	try {
	rbUseLogoFile.selected = inParams.rbUseLogoFile; 
	etWatermarkText.text = decodeURIComponent(unescape(inParams.etWatermarkText));
	ddFontFamily.selectedItem = decodeURIComponent(unescape(inParams.ddFontFamily));
	ddFontStyle.selectedItem = decodeURIComponent(unescape(inParams.ddFontStyle));
	etTextSize.text = decodeURIComponent(unescape(inParams.etTextSize)); 
	cpTextColorPicker.selectedColor = Number("0x" + inParams.cpTextColorPicker);
	cbAppendFileNames.selected = inParams.cbAppendFileNames;
	stSelectedWatermark.text = decodeURIComponent(unescape(inParams.stSelectedWatermark));
	stSelectedInput.text = decodeURIComponent(unescape(inParams.stSelectedInput));
	stSelectedOutput.text = decodeURIComponent(unescape(inParams.stSelectedOutput));
	cbUseOpenImages.selected = inParams.cbUseOpenImages;
	cbMailIt.selected = inParams.cbMailIt;
	ddMailProgram.selectedIndex = inParams.ddMailProgram;
	ddPosition.selectedItem = inParams.ddPosition;
	etWaterMarkSize.text = decodeURIComponent(unescape(inParams.etWaterMarkSize));
	etWaterMarkOpacity.text = decodeURIComponent(unescape(inParams.etWaterMarkOpacity));
	etVerticalOffset.text = decodeURIComponent(unescape(inParams.etVerticalOffset));
	etHorizontalOffset.text = decodeURIComponent(unescape(inParams.etHorizontalOffset));
	etQuality.text = decodeURIComponent(unescape(inParams.etQuality));
	etResolution.text = decodeURIComponent(unescape(inParams.etResolution));
	cbSizeToFit.selected = inParams.cbSizeToFit;
	etSizeToFitW.text = decodeURIComponent(unescape(inParams.etSizeToFitW));
	etSizeToFitH.text = decodeURIComponent(unescape(inParams.etSizeToFitH));
	rbSaveForWeb.selected = inParams.rbSaveForWeb;
	rbSaveJPEG.selected = ! rbSaveForWeb.selected;
	cbSmartSharpen.selected = inParams.cbSmartSharpen;
	cbShowSmartSharpen.selected = inParams.cbShowSmartSharpen;
	}
	catch(errObject:Error) {
		myError(errObject);
	}
}


/**
 * Function:		settingsAreValid
 * Description:		Check as many params as you can
 */
private function settingsAreValid():Boolean {
	var good:Boolean = true;
	
	var n:Number = Number(etWaterMarkSize.text);
	if (isNaN(n)) good = false;
	if (n <= 0) good = false;
	if ( ! good ) {
		myAlert("$$$/watermark/alert/invalidsize=Watermark Size is invalid!");
		return good;
	}
	
	n = Number(etWaterMarkOpacity.text);
	if (isNaN(n)) good = false;
	if (n < 0 || n > 100) good = false;
	if ( ! good ) {
		myAlert("$$$/watermark/alert/invalidopacity=Watermark Opacity is invalid!");
		return good;
	}
	
	n = Number(etQuality.text);
	if (isNaN(n)) good = false;
	if (n < 0 || n > 12) good = false;
	if ( ! good ) {
		myAlert("$$$/watermark/alert/invalidquality=Quality is invalid!");
		return good;
	}
	
	n = Number(etTextSize.text);
	if (isNaN(n)) good = false;
	if (n < 0) good = false;
	if ( ! good ) {
		myAlert("$$$/watermark/alert/invalidfontsize=Font Size is invalid!");
		return good;
	}
	
	if ( cbSizeToFit.selected ) {
		n = Number(etSizeToFitW.text);
		if ( ! isNaN(n) ) {
			if (n < 1 || n > 30000) good = false;
			if ( ! good ) {
				myAlert("$$$/watermark/alert/invalidsizetofitw=Size to fit Width is invalid!");
				return good;
			}
		}
		
		n = Number(etSizeToFitH.text);
		if ( ! isNaN(n) ) {
			if (n < 1 || n > 30000) good = false;
			if ( ! good ) {
				myAlert("$$$/watermark/alert/invalidsizetofith=Size to fit Height is invalid!");
				return good;
			}
		}
	}

	n = Number(etResolution.text);
	if (isNaN(n)) good = false;
	if (n < 0 || n > 300000) good = false;
	if ( ! good ) {
		myAlert("$$$/watermark/alert/invalidresolution=Resolution is invalid!");
		return good;
	}

	if ( ! rbUseLogoFile.selected ) {
		good = etWatermarkText.text.length != 0;
		if ( ! good ) {
			myAlert("$$$/watermark/alert/invalidneedtext=Please enter some text for your watermark!");
			return good;
		} 
	}

	return good;
}


/**
 * Function:		getCurrentSettings
 * Description:		Read in our parameters from the CSXS Preferencess
 */
private function getCurrentSettings():void {
	try {
		var version:Number = 0;
		var reqResult:SyncRequestResult = CSXSInterface.instance.evalScript("watermark.retrievePreferences");
		if (SyncRequestResult.COMPLETE == reqResult.status && reqResult.data) {
			version = Number(reqResult.data.version.toString());
			rbUseLogoFile.selected = reqResult.data.rbUseLogoFile.toString() == "true";
			etWatermarkText.text = decodeURIComponent(unescape(reqResult.data.etWatermarkText.toString()));
			ddFontFamily.selectedItem = decodeURIComponent(unescape(reqResult.data.ddFontFamily.toString()));
			
			// This is important, or the styles combo box won't update correctly
			onFontChange();

			ddFontStyle.selectedItem = decodeURIComponent(unescape(reqResult.data.ddFontStyle.toString()));
			etTextSize.text = decodeURIComponent(unescape(reqResult.data.etTextSize.toString()));
			cpTextColorPicker.selectedColor = Number("0x" + decodeURIComponent(unescape(reqResult.data.cpTextColorPicker.toString())));
			cbAppendFileNames.selected = reqResult.data.cbAppendFileNames.toString() == "true";
			stSelectedWatermark.text = decodeURIComponent(unescape(reqResult.data.stSelectedWatermark.toString()));
			stSelectedInput.text = decodeURIComponent(unescape(reqResult.data.stSelectedInput.toString()));
			stSelectedOutput.text = decodeURIComponent(unescape(reqResult.data.stSelectedOutput.toString()));
			cbMailIt.selected = reqResult.data.cbMailIt.toString() == "true";
			ddMailProgram.selectedItem = decodeURIComponent(unescape(reqResult.data.ddMailProgram.toString()));
			cbUseOpenImages.selected = reqResult.data.cbUseOpenImages.toString() == "true";
			ddPosition.selectedItem = decodeURIComponent(unescape(reqResult.data.ddPosition.toString()));
			etWaterMarkSize.text = decodeURIComponent(unescape(reqResult.data.etWaterMarkSize.toString()));
			etHorizontalOffset.text = decodeURIComponent(unescape(reqResult.data.etHorizontalOffset.toString()));
			etVerticalOffset.text = decodeURIComponent(unescape(reqResult.data.etVerticalOffset.toString()));
			etWaterMarkOpacity.text = decodeURIComponent(unescape(reqResult.data.etWaterMarkOpacity.toString()));
			etQuality.text = decodeURIComponent(unescape(reqResult.data.etQuality.toString()));
			cbSizeToFit.selected = reqResult.data.cbSizeToFit.toString() == "true";
			cbSmartSharpen.selected = reqResult.data.cbSmartSharpen.toString() == "true";
			cbShowSmartSharpen.selected = reqResult.data.cbShowSmartSharpen.toString() == "true";
			etSizeToFitW.text = decodeURIComponent(unescape(reqResult.data.etSizeToFitW.toString()));
			etSizeToFitH.text = decodeURIComponent(unescape(reqResult.data.etSizeToFitH.toString()));
			etResolution.text = decodeURIComponent(unescape(reqResult.data.etResolution.toString()));
			rbSaveForWeb.selected = reqResult.data.rbSaveForWeb.toString() == "true";
			accordionMain.selectedIndex = Number(reqResult.data.accordionMain.toString());
			showHelpMessage = reqResult.data.showHelpMessage.toString() == "true";

		} else {
			; // do nothing
		}
	}
    catch(e:Error) { 
 		; // do nothing
	}
}


/**
 * Function:		saveCurrentSettings
 * Description:		Save off our settings for later use
 */
private function saveCurrentSettings(params:String):void {
	var reqResult:SyncRequestResult = csxs.evalScript("watermark.storePreferences", params);
	if (SyncRequestResult.COMPLETE == reqResult.status) {
		; // I hope that worked
  	}
}


/**
 * Function:		selectFolder
 * Description:		Get the folder for input (true) or output (false)
 */
private function selectFolder(inputFolder:Boolean):void{
	try {
		var lastFolder:String = inputFolder ? stSelectedInput.text : stSelectedOutput.text;
		var reqResult:SyncRequestResult = csxs.evalScript("watermark.selectFolder", encodeURIComponent(lastFolder));
		if (SyncRequestResult.COMPLETE == reqResult.status) {
			if (reqResult.data.error == 0) {
				if (inputFolder) {
					stSelectedInput.text = decodeURIComponent(unescape(reqResult.data.message));
					stSelectedInput.toolTip = stSelectedInput.text;
				} else {
        			stSelectedOutput.text = decodeURIComponent(unescape(reqResult.data.message));
        			stSelectedOutput.toolTip = stSelectedOutput.text;
    			}
   			}
  		}
	}
  	catch (errObject:Error) {
  		myError(errObject);
  	}
}


/**
 * Function:		selectWatermark
 * Description:		Pick the watermark file
 */
private function selectWatermark():void {
	try {
		var reqResult:SyncRequestResult = csxs.evalScript("watermark.selectWatermark");
		if (SyncRequestResult.COMPLETE == reqResult.status) {
			if (reqResult.data.error == 0) {
        		stSelectedWatermark.text = decodeURIComponent(unescape(reqResult.data.message));
        		stSelectedWatermark.toolTip = stSelectedWatermark.text;
   			}
  		}
	}
  	catch (errObject:Error) {
  		myError(errObject);
  	}
}


/**
 * Function:		rgbToHex
 * Description:		A nifty function that converts a number to 
 * 					a hexidecimal string.
 */

private function rgbToHex(color:uint):String
{
	// Find hex number in the RGB offset
	var colorInHex:String = color.toString(16);
	var c:String = "00000" + colorInHex;
	var e:int = c.length;
	c = c.substring(e - 6, e);
	return c.toLowerCase();
}


/**
 * Function:        localize
 * Description:     Get localized zstring
 */
private function localize(str:String):String{
    try {
        var reqResult:SyncRequestResult = csxs.evalScript("watermark.getZstring", escape(encodeURIComponent(str)));
        if (SyncRequestResult.COMPLETE == reqResult.status) {
			return decodeURIComponent(unescape(reqResult.data.zstring));
        }
    }
    catch (errObject:Error) {
        myError(errObject);
    }
    return "";
}


/**
 * Function:	updatePanelMenu
 * Description:	Change the panel menu strings with our localized version
 */
private function updatePanelMenu():void {
	try {

		var xmlMenu:XML = <Menu>
              <MenuItem Label="testing"/>
              <MenuItem Label="bingo"/>
              <MenuItem Label="bango"/>
              <MenuItem Label="Help!"/>
              <MenuItem Label="V1"/>
           	  </Menu>;
           	  
        xmlMenu.MenuItem[0].@Label = strLoadText;
        xmlMenu.MenuItem[1].@Label = strSaveText;
        xmlMenu.MenuItem[2].@Label = strResetText;
        xmlMenu.MenuItem[3].@Label = strHelpText;
        xmlMenu.MenuItem[4].@Label = strVersionText;
     
		var result:SyncRequestResult = csxs.setPanelMenu(xmlMenu);
		csxs.addEventListener(MenuClickEvent.FLYOUT_MENU_CLICK, onMenuHandler);
	}

  	catch (errObject:Error) {
        myError(errObject);
  	}
}


/**
 * Function:	onMenuHandler
 * Description:	User picked a menu item, do something interesting
 */
private function onMenuHandler(inEvent:MenuClickEvent):void {
	try {
		var reqResult:SyncRequestResult;
		if (strLoadText == inEvent.menuName) {
			reqResult = csxs.evalScript("watermark.loadParamsFromDisk");
			if (SyncRequestResult.COMPLETE == reqResult.status) {
				if (reqResult.data.error == 0) {
					paramsFromParams(reqResult.data);
					updateUIFromCurrentSettings();
   				} else {
   					myAlert("$$$/watermark/alert/invalidparamsfile=Could not read the settings from the file!");
   				}
  			} else {
  				myAlert("$$$/watermark/alert/invalidparamsfile=Could not read the settings from the file!");
  			}
		} else if (strSaveText == inEvent.menuName) {
			var params:String = paramsToParams(/* onOneImage */ true);
			reqResult = csxs.evalScript("watermark.saveParamsToDisk", params);
		} else if (strResetText == inEvent.menuName) {
			resetToDefaults();
			updateUIFromCurrentSettings();
		} else if (strHelpText == inEvent.menuName) {
			reqResult = csxs.evalScript("watermark.runHelp");
		}
	}
	catch(errObject:Error) {
		myError(errObject);
	}
}	


/**
 * Function:		maybeShowHelp
 * Description:		See if we have asked them to show the help video, we do this only once
 * 
 *                  showHelpMessage is saved immediately and read from preferences before calling
 */
private function maybeShowHelp():void {
	if (showHelpMessage) {
		showHelpMessage = false;
		var showIt:Boolean = myConfirm("$$$/watermark/wouldyou=Would you like to see the help video for Watermark now?");
		if (showIt) {
			csxs.evalScript("watermark.runHelp");
		}
	}
}


/**
 * Function:		myConfirm
 * Description:		Pop the ExtendScript confirm dialog with a question and return yes (true) or no (false
 */
private function myConfirm(msg:String):Boolean {
	try {
		var reqResult:SyncRequestResult = csxs.evalScript("watermark.myConfirm", escape(encodeURIComponent(msg)));
		if (SyncRequestResult.COMPLETE == reqResult.status) {
			return reqResult.data.myConfirm == "true";
    	}
	}
    catch (errObject:Error) {
    	;
	}
	return false;
}


/**
 * Function:	myAlert
 * Description:	Use Extend Script to show an alert
 */
private function myAlert(msg:String):void {
	// This is the Flex version Alert.show(msg, strAlertText, Alert.OK, Sprite(mx.core.Application.application));
	var reqResult:SyncRequestResult = csxs.evalScript("watermark.myAlert", escape(encodeURIComponent(msg)));
}


/**
 * Function:	myError
 * Description:	Sorry, I messed up, let the user know
 */
private function myError(err:Error):void {
	if (showErrors)
		myAlert("$$$/private/WatermarkError=" + err.message + " " + err.errorID.toString() + " " + err.name);
}

// end Watermark.as
